; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.


;-| AI |--------------------------------------------------------
[Command]
name = "Ankoku-AsurA-TaG"
command = s
time = 1
[Command]
name =  "AsuAtras"
command = B
time = 1
[Command]
name =  "AsuAdelante"
command = F
time = 1
[Command]
name =  "AsuAbajo"
command = D
time = 1
[Command]
name =  "AsuArriba"
command = U
time = 1
[command]
name = "AI1"
command = B,D,a+c,z,c+b,s
time = 1
[command]
name = "AI2"
command = B,F,c+b,z,c+z,x,s
time = 1
[command]
name = "AI3"
command = B,U,a+b,y,c+y,s,z,D
time = 1
[command]
name = "AI4"
command = B,B,a+y,c,z+x,s
time = 1
[command]
name = "AI5"
command = B,B,a+b,z,c+b,s
time = 1
[command]
name = "AI6"
command = D,B,z+b,z,c+x,s
time = 1
[command]
name = "AI7"
command = B,U,a+b,z,c+x,s
time = 1
[command]
name = "AI8"
command = B,F,a+b,c,c+x,s
time = 1
[Command]
name = "AI9"
command = U,D,F,F,B,B,s
time = 1
[Command]
name = "AI10"
command = U,D,F,F,B,F,s
time = 1
[Command]
name = "AI11"
command = U,D,F,F,B,D,s
time = 1
[Command]
name = "AI12"
command = U,D,F,F,B,U,s
time = 1
[Command]
name = "AI13"
command = U,D,F,F,U,B,s
time = 1
[Command]
name = "AI14"
command = U,D,F,F,D,B,s
time = 1
[Command]
name = "AI15"
command = U,D,F,F,F,B,s
time = 1
[Command]
name = "AI16"
command = U,D,U,F,B,B,s
time = 1
[Command]
name = "AI17"
command = U,D,D,F,B,B,s
time = 1
[Command]
name = "AI18"
command = D,D,F,F,B,B,s
time = 1
[Command]
name = "AI19"
command = U,U,F,F,B,B,s
time = 1
[Command]
name = "AI20"
command = U,B,F,F,B,B,s
time = 1
[Command]
name = "AI21"
command = UB, U, F, a+b,s
time = 1
[Command]
name = "AI22"
command = UB, U, F, b+c,s
time = 1
[Command]
name = "AI23"
command = UB, U, F, a+c,s
time = 1
[Command]
name = "AI24"
command = UF, U, B, x+y,s
time = 1
[Command]
name = "AI25"
command = UF, U, B, y+z,s
time = 1
[Command]
name = "AI26"
command = UF, U, B, x+z,s
time = 1
[Command]
name = "AI27"
command = UB, U, F, x+y,s
time = 1
[Command]
name = "AI28"
command = UB, U, F, y+z,s
time = 1
[Command]
name = "AI29"
command = UB, U, F, x+z,s
time = 1
[Command]
name = "AI30"
command = UF, U, B, a+b,s
time = 1
[Command]
name = "AI31"
command = UF, U, B, b+c,s
time = 1
[Command]
name = "AI32"
command = UF, U, B, a+c,s
time = 1
[Command]
name = "AI33"
command = UF, DB, UB,DF ,x,s
time = 1
[Command]
name = "AI34"
command = UF, DB, UB,DF ,y,s
time = 1
[Command]
name = "AI35"
command = UF, DB, UB,DF , z,s
time = 1

;-| Super Motions |--------------------------------------------------------

[Command]
name = "Spunches_x"
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = "Spunches_y"
command = ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = "Spunches_z"
command = ~D, DF, F, D, DF, F, z
time = 30

[Command]
name = "Skick_a"
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = "Skick_b"
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = "Skick_c"
command = ~D, DF, F, D, DF, F, c
time = 30
;-| Special Motions |------------------------------------------------------
;-----------------
; specials
[Command]
name = "Jagkick_a"
command = ~B, D, DB, a

[Command]
name = "Jagkick_b"
command = ~B, D, DB, b

[Command]
name = "Jagkick_c"
command = ~B, D, DB, c



[Command]
name = "Jagtooth_a"
command = ~F, DF, D, DB, B, a
time = 20

[Command]
name = "Jagtooth_b"
command = ~F, DF, D, DB, B, b
time = 20

[Command]
name = "Jagtooth_c"
command = ~F, DF, D, DB, B, c
time = 20



[Command]
name = "ff_a"
command = F, F, a
time = 15

[Command]
name = "ff_b"
command = F, F, b
time = 15

[Command]
name = "ff_c"
command = F, F, c
time = 15

[Command]
name = "ff_x"
command = F, F, x
time = 15

[Command]
name = "ff_y"
command = F, F, y
time = 15

[Command]
name = "ff_z"
command = F, F, z
time = 15


;-----------------
; QCF
[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = c+z
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "fab"
command = /F, a+b
time = 3

[Command]
name = "ab"
command = /B, a+b
time = 3

[Command]
name = "bc"
command = b+c
time = 1

[Command]
name = "fbc"
command = /F, b+c
time = 3

[Command]
name = "bc"
command = /B, b+c
time = 3

[Command]
name = "xy"
command = x+y
time = 1

[Command]
name = "yz"
command = y+z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "back_x"
command = /B,x
time = 1

[Command]
name = "back_y"
command = /B,y
time = 1

[Command]
name = "back_z"
command = /B,z
time = 1


[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1


;-| Hold Button |-----------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1


;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
triggerall = Var(31) != 1
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
triggerall = Var(31) != 1
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;kick_Throw (close dir+kick)
[State -1]
type =  ChangeState
value = 2500
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 10
triggerall = stateno != 100 
triggerall = p2statetype = S
triggerall = p2statetype != A	
triggerall = p2statetype != C
triggerall = p2movetype != H
trigger1 = command = "back_a"
trigger2 = command = "back_b"
trigger3 = command = "back_c"

;kick_Throw reversed (close dir+kick)
[State -1]
type =  ChangeState
value = 2505
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5
triggerall = stateno != 100 
triggerall = p2statetype = S
triggerall = p2statetype != A	
triggerall = p2statetype != C
triggerall = p2movetype != H
trigger1 = command = "fwd_a"
trigger2 = command = "fwd_b"
trigger3 = command = "fwd_c"

;punch_Throw (close dir+punch)
[State -1]
type =  ChangeState
value = 2510
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5
triggerall = stateno != 100 
triggerall = p2statetype = S
triggerall = p2statetype != A	
triggerall = p2statetype != C
triggerall = p2movetype != H
trigger1 = command = "fwd_x"
trigger2 = command = "fwd_y"
trigger3 = command = "fwd_z"


;punch_Throw reversed (close dir+punch)
[State -1]
type =  ChangeState
value = 2515
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 10
triggerall = stateno != 100 
triggerall = p2statetype = S
triggerall = p2statetype != A	
triggerall = p2statetype != C
triggerall = p2movetype != H
trigger1 = command = "back_x"
trigger2 = command = "back_y"
trigger3 = command = "back_z"

;===========================================================================
;---------------------------------------------------------------------------
;Punches combo
;light
[State -1]
type = ChangeState
value = 3020
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = power >= 1000
trigger1 = command = "Spunches_x"
trigger2 = power >= 1000
trigger2 = power < 2000
trigger2 = command = "Spunches_y"
trigger3 = power >= 1000
trigger3 = power < 2000
trigger3 = command = "Spunches_z"


;medium
[State -1]
type = ChangeState
value = 3010
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = power >= 2000
trigger1 = command = "Spunches_y"
trigger2 = power >= 2000
trigger2 = power < 3000
trigger2 = command = "Spunches_z"

;heavy
[State -1]
type = ChangeState
value = 3000
triggerall = Var(31) != 1
triggerall = command = "Spunches_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power = 3000

;---------------------------------------------------------------------------
;kick combo
;light
[State -1]
type = ChangeState
value = 3120
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = power >= 1000
trigger1 = command = "Skick_a"
trigger2 = power >= 1000
trigger2 = power < 2000
trigger2 = command = "Skick_b"
trigger3 = power >= 1000
trigger3 = power < 2000
trigger3 = command = "Skick_c"


;medium
[State -1]
type = ChangeState
value = 3110
triggerall = Var(31) != 1
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = power >= 2000
trigger1 = command = "Skick_b"
trigger2 = power >= 2000
trigger2 = power < 3000
trigger2 = command = "Skick_c"

;heavy
[State -1]
type = ChangeState
value = 3100
triggerall = Var(31) != 1
triggerall = command = "Skick_c"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power = 3000

;---------------------------------------------------------------------------
;Jaguar_Tooth_a
[State -1]
type = ChangeState
value = 2000
triggerall = Var(31) != 1
triggerall = command = "Jagtooth_a"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jaguar_Tooth_b
[State -1]
type = ChangeState
value = 2100
triggerall = Var(31) != 1
triggerall = command = "Jagtooth_b"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jaguar_Tooth_c
[State -1]
type = ChangeState
value = 2200
triggerall = Var(31) != 1
triggerall = command = "Jagtooth_c"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jaguar_a
[State -1]
type = ChangeState
value = 1000
triggerall = Var(31) != 1
triggerall = command = "uppercut_a"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Jaguar_b
[State -1]
type = ChangeState
value = 1100
triggerall = Var(31) != 1
triggerall = command = "uppercut_b"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Jaguar_c
[State -1]
type = ChangeState
value = 1200
triggerall = Var(31) != 1
triggerall = command = "uppercut_c"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jaguar_kick_a
[State -1]
type = ChangeState
value = 1001
triggerall = Var(31) != 1
triggerall = command = "Jagkick_a"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jaguar_kick_b
[State -1]
type = ChangeState
value = 1101
triggerall = Var(31) != 1
triggerall = command = "Jagkick_b"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jaguar_kick_c
[State -1]
type = ChangeState
value = 1201
triggerall = Var(31) != 1
triggerall = command = "Jagkick_c"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 210
triggerall = Var(31) != 1
triggerall = command = "a";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 211
triggerall = Var(31) != 1
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact  ;If move hits, or is guarded by opponent
trigger3 = stateno = 200
trigger3 = movecontact
trigger4 = stateno = 201
trigger4 = movecontact

;----------------------------------------------------------------------------
;Stand_C - Close
[State -1]
type = ChangeState
value = 215
triggerall = Var(31) != 1
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 36
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 211
trigger2 = movecontact
trigger3 = stateno = 201
trigger3 = movecontact

;----------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 212
triggerall = Var(31) != 1
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 211
trigger2 = movecontact
trigger3 = stateno = 201
trigger3 = movecontact


;Stand_C
;[State -1]
;type = ChangeState
;value = 444205
;triggerall = Var(31) != 1
;triggerall = command = "s"
;triggerall = command != "holddown"
;triggerall = statetype = S
;trigger1 = ctrl = 1
;trigger2 = stateno = 211
;trigger2 = movecontact
;trigger3 = stateno = 201
;trigger3 = movecontact

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 410
triggerall = Var(31) != 1
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 411
triggerall = Var(31) != 1
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 410
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouch_C
[State -1]
type = ChangeState
value = 412
triggerall = Var(31) != 1
triggerall = command = "c"
triggerall = command = "holddown"
triggerall = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 411
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 610
triggerall = Var(31) != 1
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 611
triggerall = Var(31) != 1
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 612
triggerall = Var(31) != 1
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_X
[State -1]
type = ChangeState
value = 200
triggerall = Var(31) != 1
triggerall = command = "x";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand_forward + Y
[State -1]
type = ChangeState
value = 205
triggerall = Var(31) != 1
triggerall = command = "fwd_y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Y
[State -1]
type = ChangeState
value = 201
triggerall = Var(31) != 1
triggerall = command = "y";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 211
trigger4 = movecontact

;---------------------------------------------------------------------------
;Stand_Z
[State -1]
type = ChangeState
value = 202
triggerall = Var(31) != 1
triggerall = command = "z";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact
trigger3 = stateno = 211
trigger3 = movecontact

;---------------------------------------------------------------------------
;Crouch_X
[State -1]
type = ChangeState
value = 400
triggerall = Var(31) != 1
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 401
triggerall = Var(31) != 1
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouch_Z
[State -1]
type = ChangeState
value = 402
triggerall = Var(31) != 1
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 401
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 600
triggerall = Var(31) != 1
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 601
triggerall = Var(31) != 1
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Z
[State -1]
type = ChangeState
value = 602
triggerall = Var(31) != 1
trigger1 = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Taunt
[State -1]
type = ChangeState
value = 195
triggerall = Var(31) != 1
trigger1 = command = "s"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Zero/Alpha Counter
[State -1]
type = ChangeState
value = 900
triggerall = Var(31) != 1
triggerall = StateNo >= 150
triggerall = StateNo <= 153
trigger1 = Command = "QCB_a"
trigger2 = Command = "QCB_b"
trigger3 = Command = "QCB_c"
trigger4 = Command = "ff_a"
trigger5 = Command = "ff_b"
trigger6 = Command = "ff_c"

;---------------------------------------------------------------------------
;Recovery Roll 
[State -1]
type = ChangeState
value = 910
triggerall = Var(31) != 1
triggerall = command = "fbc"
triggerall = alive = 1
trigger1 = stateno = 5050
trigger2 = stateno = 5071

;Recovery Roll 
[State -1]
type = ChangeState
value = 915
triggerall = Var(31) != 1
triggerall = command = "bc"
triggerall = alive = 1
trigger1 = stateno = 5050
trigger2 = stateno = 5071

;Recovery Roll 
[State -1]
type = ChangeState
value = 910
triggerall = Var(31) != 1
triggerall = command = "fab"
triggerall = alive = 1
trigger1 = stateno = 5050
trigger2 = stateno = 5071

;Recovery Roll 
[State -1]
type = ChangeState
value = 915
triggerall = Var(31) != 1
triggerall = command = "ab"
triggerall = alive = 1
trigger1 = stateno = 5050
trigger2 = stateno = 5071

;Evade Roll 
[State -1]
type = ChangeState
value = 910
triggerall = Var(31) != 1
triggerall = StateNo >= 150
triggerall = StateNo <= 153
trigger1 = Command = "QCB_x"
trigger2 = Command = "QCB_y"
trigger3 = Command = "QCB_z"
trigger4 = Command = "ff_x"
trigger5 = Command = "ff_y"
trigger6 = Command = "ff_z"



[State -2, 0] 
type = varset
triggerall = var(55) = 0
trigger1 = command = "AI1"
trigger2 = command = "AI2"
trigger3 = command = "AI3"
trigger4 = command = "AI4"
trigger5 = command = "AI5"
trigger6 = command = "AI6"
trigger7 = command = "AI7"
trigger8 = command = "AI8"
trigger9 = command = "AI9"
trigger10 = command = "AI10"
trigger11 = command = "AI11"
trigger12 = command = "AI12"
trigger13 = command = "AI13"
trigger14 = command = "AI14"
trigger15 = command = "AI15"
trigger16 = command = "AI16"
trigger17 = command = "AI17"
trigger18 = command = "AI18"
trigger19 = command = "AI19"
trigger20 = command = "AI20"
trigger21 = command = "AI21"
trigger22 = command = "AI22"
trigger23 = command = "AI23"
trigger24 = command = "AI24"
trigger25 = command = "AI25"
trigger26 = command = "AI26"
trigger27 = command = "AI27"
trigger28 = command = "AI28"
trigger29 = command = "AI29"
trigger30 = command = "AI30"
trigger31 = command = "AI31"
trigger32 = command = "AI32"
trigger33 = command = "AI33"
trigger34 = command = "AI34"
trigger35 = command = "AI35"
var(31) = 1


[state -2]
type = ChangeState
triggerall = Var(31) = 1
triggerall = statetype = S 
triggerall = p2movetype = A 
triggerall = p2statetype != C
triggerall = ctrl
trigger1 = enemy, numproj > 0
trigger1 = p2bodydist X <= 150
trigger1 = Random <= 900
value = 130

[state -2]
type = ChangeState
triggerall = Var(31) = 1
triggerall = statetype = S 
triggerall = p2movetype = A 
triggerall = p2statetype != C
triggerall = ctrl
trigger1 = enemy, numproj > 0
;trigger1 = Random <= 900
value = 910

[state -2]
type = ChangeState
triggerall = Var(31) = 1
triggerall = statetype = S
triggerall = p2movetype = A
triggerall = ctrl
trigger1 = p2bodydist X <= 150
trigger1 = StateNo = 150
value = 152

[state -2]
type = ChangeState
triggerall = Var(31) = 1
triggerall = statetype = C
triggerall = p2movetype = A
triggerall = ctrl
trigger1 = enemy, numproj > 0
;trigger1 = random <= 900
trigger2 = p2bodydist X <= 150
value = 131

[state -2]
type = ChangeState
triggerall = Var(31) = 1
triggerall = statetype = C
triggerall = p2movetype = A
triggerall = ctrl
triggerall = P2statetype != C
trigger1 = p2bodydist X <= 150
trigger2 = StateNo = 152
value = 150

[state -2]
type = ChangeState
triggerall = Var(31) = 1
triggerall = Statetype = A
triggerall = P2Movetype = A
triggerall = Ctrl
trigger1 = enemy, numproj > 0
trigger2 = p2bodydist X <= 150
value = 132 

[state -2]
type = ChangeState
value =  205;555200
triggerall = Var(31) = 1
triggerall = StateType = S
triggerall = p2StateType = S && P2StateType != A && P2StateType != C
triggerall = roundstate = 2
triggerall = stateno < 800 
trigger1 = P2BodyDist X = [25,39]
trigger1 = ctrl = 1

[state -2]
type = ChangeState
value = 410
triggerall = Var(31) = 1
triggerall = Life != 0
triggerall = p2bodydist X <= 40
triggerall = roundstate = 2
triggerall = ctrl
triggerall = StateType != A && MoveType != H
triggerall = p2stateno = [5050,5110]
trigger1 = enemy, numproj = 0
trigger2 = p2movetype != A

[state -2]
type = changestate
value = 410
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H 
triggerall = ctrl && p2life!= 0
triggerall = random <= 499
triggerall = P2BodyDist X = [00,15]
triggerall = P2StateType != A
triggerall = enemy, numproj = 0
triggerall = p2stateno = [5000,5999]
trigger1 = 1
trigger2 = p2stateno = 1006
trigger2 = time >= 15

[state -2]
type = changestate
value = 410
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H 
triggerall = ctrl && p2life!= 0
triggerall = P2BodyDist X = [00,15]
triggerall = P2StateType != A
triggerall = enemy, numproj = 0
triggerall = p2stateno = [5000,5999]
trigger1 = 1
trigger2 = p2stateno = 1006
trigger2 = time >= 15

[state -2]
type = changestate
value =  444205;444410
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H 
triggerall = ctrl && p2life!= 0
triggerall = P2BodyDist X = [-10,30]
triggerall = P2BodyDist Y = [-30,-1]
triggerall = p2StateType = A
trigger1 = p2stateno = [5000,5999]
trigger2 = 1
trigger3 = p2stateno = 1006
trigger3 = time >= 15


[state -2]
type = changestate
value = 1000;5551000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H 
triggerall = ctrl && p2life!= 0
triggerall = stateno != 3050
triggerall = stateno != 3000
triggerall = P2BodyDist X = [-2,29]
triggerall = P2BodyDist Y = [-60,-1]
triggerall = p2StateType = A
trigger1 = p2stateno = [5000,5999]
trigger2 = 1
trigger3 = p2stateno = 1006
trigger3 = time >= 15

[state -2]
type = changestate
value =  444205;4441000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A 
triggerall = Stateno != 150
triggerall = Stateno != 151
triggerall = stateno != 3050
triggerall = stateno != 3000
triggerall = ctrl && p2life!= 0
triggerall = P2BodyDist X = [-40,68]
trigger1 = p2stateno = [5000,5999]
trigger2 = 1
trigger3 = p2stateno = 1006
trigger3 = time >= 15

[state -2]
type = ChangeState
value = 611
triggerall = (roundstate != [0,1]) || (roundstate != [3,4])
triggerall = Var(31) = 1 
triggerall = StateType = A && MoveType != H 
triggerall = ctrl && p2life!= 0
trigger1 = P2BodyDist X = [-5,30]
trigger1 = P2BodyDist Y = [-10,10]
trigger1 = p2MoveType = H

[state -2]
type = changestate
value = 3020 ;+ (power >= 2000)*50
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && random > life && time % 4 
triggerall = StateType != A && MoveType != H && power >= 1000
triggerall = p2life!= 0
triggerall = ctrl && P2movetype = A  
triggerall = P2BodyDist X = [-50,50] 
triggerall = P2BodyDist Y >= -150
trigger1 = p2stateno = 50
trigger2 = p2stateno = [5050,5070]
trigger3 = p2stateno = [5100,5102]
trigger4 = p2stateno = 5110
trigger5 = p2stateno = 5200
trigger6 = 1
trigger7 = enemy, numproj >= 0
trigger8 = stateno < 800 && random >=501

[state -2]
type = changestate
value = 3020 ;+ (power >= 2000)*50
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 
triggerall = StateType != A && MoveType != H && power >= 1000
triggerall = ctrl && P2movetype = A  && stateno < 800 && random <=500
triggerall = P2BodyDist X = [-50,50] 
triggerall = P2BodyDist Y >= -120
triggerall = p2life!= 0
trigger1 = p2stateno = 50
trigger2 = p2stateno = [5050,5070]
trigger3 = p2stateno = [5100,5102]
trigger4 = p2stateno = 5110
trigger5 = p2stateno = 5200
trigger6 = 1
trigger7 = enemy, numproj >= 0

[state -2]
type = changestate
value = 2000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H && p2life!= 0
triggerall = ctrl
triggerall = P2BodyDist X = [10,60]
triggerall = P2BodyDist Y <= -20
triggerall = p2movetype != H
trigger1 = p2movetype = A
trigger1 = random < 989
trigger2 = p2statetype = A
trigger2 = random < 989

[state -2]
type = changestate
value = 610
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType = A && MoveType != H && p2life!= 0
triggerall = ctrl
triggerall = P2BodyDist X = [0,220]
triggerall = P2BodyDist Y = [-5,150]
trigger1 = p2MoveType = A
trigger1 = random >= 50
trigger2 = enemy, Numproj > 0 && random >= 10
trigger3 = enemy, Numhelper > 0 && random >= 10
trigger4 = p2stateno = [5000,5999]





[state -2]
type = changestate
value = 1000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1
triggerall = statetype != A
triggerall = ctrl
triggerall = P2BodyDist X = [10,150]
trigger1 = p2movetype = A
trigger1 = random >= 50
;trigger2 = enemy, Numproj > 0
;trigger3 = enemy, Numhelper > 0


[state -2]
type = changestate
value = 1000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 
triggerall = statetype != A
triggerall = ctrl
triggerall = p2name = "Evil Ryu"
triggerall = P2BodyDist X = [10,150]
triggerall = P2stateno = 1862
trigger1 = p2movetype = A
trigger1 = random >= 50
trigger2 = enemy, Numproj > 0
trigger3 = enemy, Numhelper > 0

[state -2]
type = changestate
value = 2100
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 
triggerall = statetype != A
triggerall = ctrl
triggerall = p2movetype = A
triggerall = P2BodyDist X <= 56
trigger1 = random >= 0
trigger2 = enemy, Numproj > 0
trigger3 = enemy, Numhelper > 0

[state -2]
type = changestate
value = 1000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 
triggerall = statetype != A
triggerall = ctrl
triggerall = P2BodyDist X = [-80,80] 
triggerall = P2statetype = A
trigger1 = p2movetype = A
trigger2 = enemy, Numproj > 0 && random >= 10
trigger3 = enemy, Numhelper > 0 && random >= 10

[state -2]
type = ChangeState
value = 2510
triggerall = Var(31) = 1
triggerall = Life != 0 && stateno < 600
triggerall = p2bodydist X <= 35
triggerall = roundstate = 2 && ctrl = 1
triggerall = StateType != A && MoveType != H
triggerall = p2statetype != A
triggerall = p2statetype != L
triggerall = random <= 400
triggerall = p2stateno != [5000,5999]
triggerall = movetype != H 
trigger1 = enemy, numproj = 0
trigger2 = p2movetype != A;AI Ground Throw



[state -2]
type = ChangeState
value = 1001
triggerall = Var(31) = 1 
triggerall = Life != 0 && stateno < 600
triggerall = p2bodydist X = [125,196]
triggerall = roundstate = 2 && ctrl = 1
triggerall = StateType != A && MoveType != H
triggerall = P2MoveType != H
triggerall = P2StateNo != 40
triggerall = StateNo != 195
triggerall = p2statetype != A
triggerall = p2statetype != L
triggerall = p2stateno != [5000,5999]
triggerall = movetype != H 
triggerall = random > 500
trigger1 = enemy, numproj = 0
trigger2 = p2movetype != A


;===================================
[state -2]
type = ChangeState
value = 900
triggerall = Var(31) = 1 
triggerall = StateType != A
triggerall = P2life != 0
trigger1 = P2BodyDist x <= 130
trigger1 = StateNo = [150,153]
;trigger1 = Random = [0,500]

[state -2]
type = ChangeState
value = 910
triggerall = Var(31) = 1 
triggerall = StateType = A 
triggerall = P2life != 0
trigger1 = P2BodyDist x <= 130
trigger1 = StateNo = [150,155]
;trigger1 = Random = [0,500]

[state -2]
type = ChangeState
value = 105
triggerall = Var(31) = 1
triggerall = prevstateno != 52
triggerall = random <= 499
triggerall = stateno = 52
trigger1 = stateno = 52

[state -2]
type = ChangeState
value = 910
triggerall = Var(31) = 1
triggerall = stateno = 52
trigger1 = stateno = 52

[state -2]
type = ChangeState
value = 105
triggerall = Var(31) = 1
triggerall = prevstateno != 52
triggerall = stateno = 444205 && time = 16
triggerall = random <= 499
trigger1 = stateno = 444205 && time = 16


[state -2]
type = ChangeState
value = 910
triggerall = Var(31) = 1
triggerall = stateno = 444205 && time = 16
trigger1 = stateno = 444205 && time = 16


[state -2]
type = ChangeState
value = 105
triggerall = Var(31) = 1
triggerall = stateno = 52
triggerall = prevstateno != 52
triggerall = random <= 499
triggerall = p2stateno != [5000,5999]
trigger1 = Prevstateno = 1000


[state -2]
type = ChangeState
value = 910
triggerall = Var(31) = 1
triggerall = stateno = 52
triggerall = p2stateno != [5000,5999]
trigger1 = Prevstateno = 1000


[state -2]
type = ChangeState
value = 910
triggerall = Var(31) = 1
triggerall = stateno = 52
triggerall = p2stateno != [5000,5999]
trigger1 = stateno = 52

[state -2]
type = ChangeState
value = 1001
triggerall = Var(31) = 1
triggerall = power >= 1000
triggerall = statetype = S
trigger1 = p2stateno = 195


[state -2]
type = ChangeState
value = 1001
triggerall = Var(31) = 1
triggerall = power >= 1000
triggerall = statetype = S
trigger1 = p2stateno = 805



[state -2]
type = ChangeState
value = 1001
triggerall = Var(31) = 1
triggerall = stateno != 1410
triggerall = power < 999
triggerall = statetype = S
trigger1 = p2stateno = 805

[state -2]
type = ChangeState
value = 1001
triggerall = Var(31) = 1
triggerall = power >= 1000
triggerall = statetype = S
trigger1 = p2stateno = 850


[state -2]
type = ChangeState
value = 1001
triggerall = Var(31) = 1
triggerall = stateno != 1410
triggerall = power < 999
triggerall = statetype = S
trigger1 = p2stateno = 850


[state -2]
type = ChangeState
value = 1001
triggerall = Var(31) = 1
triggerall = power < 999
triggerall = stateno != 1410
triggerall = statetype = S
trigger1 = p2stateno = 195



[state -2]
type = ChangeState
value = 910
triggerall = Var(31) = 1
triggerall = stateno = 100 
trigger1 = enemy,numproj >= 1


[state -2]
type = ChangeState
value = 444205;4441000
triggerall = StateType != A
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno < 800 
triggerall = movehit
triggerall = random <= 332
trigger1 = P2BodyDist X = [-5,90]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [-5,90]
;trigger2 = prevstateno = 300


[state -2]
type = ChangeState
value = 444205;4441000
triggerall = StateType != A
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno = 1001
triggerall = movehit
trigger1 = P2BodyDist X = [-5,90]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [-5,90]
;trigger2 = prevstateno = 300


[state -2]
type = ChangeState
value = 444205;4441000 
triggerall = StateType = S
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno <= 800 
triggerall = moveguarded
trigger1 = P2BodyDist X = [5,95]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [5,55]
;trigger2 = prevstateno = 200


[state -2]
type = ChangeState
value = 444205;4441000 
triggerall = StateType = S
;triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = prevstateno = 1001
triggerall = stateno = 52
;triggerall = moveguarded
trigger1 = P2BodyDist X = [5,95]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [5,55]
;trigger2 = prevstateno = 200



[state -2]
type = ChangeState
value = 444205;5551000
triggerall = StateType != A
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno < 600 
triggerall = random <= 299
triggerall = movehit
trigger1 = P2BodyDist X = [-5,90]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [-5,90]
;trigger2 = prevstateno = 200



[state -2]
type = ChangeState
value = 444205;7771000
triggerall = StateType != A
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno < 800 
triggerall = movehit
trigger1 = P2BodyDist X = [-5,90]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [-5,90]
;trigger2 = prevstateno = 200



[state -2]
type = ChangeState
value = 100
triggerall = Movetype != A 
triggerall = P2Movetype != A && ctrl 
triggerall = stateno != 100 
triggerall = Var(31) = 1
triggerall = pos y = 0
trigger1 = (p2stateno = 5120 || p2stateno = 5100 || p2stateno = 5050 || p2statetype = S) && p2bodydist x >= 100
trigger1 = p2movetype != A && random < 300 && statetype != A
trigger2 = ProjGuardedTime(221) >= 1
trigger2 = ctrl && random < 999



[State -1]
type = ChangeState
triggerall = stateno = 100 &&  var(31) = 1
trigger1 = P2movetype != I && p2movetype != H
trigger1 = p2bodydist x < 2 
value = 0
ctrl = 1
[state -2]
type = ChangeState
triggerall =  Statetype != A && P2statetype != C && Statetype = S && P2Movetype = A && Var(31) = 1
triggerall = (Pos Y != [-1,-999]) && ctrl = 1
trigger1 = random <= 900
value = 130 

[state -2]
type = ChangeState
triggerall = StateType != A && P2statetype = C && P2Movetype = A && Var(31) = 1
triggerall = Pos Y != [-1,-999]
trigger1 = 1 &&  stateno = 150
value = 152

[state -2]
type = ChangeState
triggerall = StateType != A && P2statetype = C && P2Movetype = A && Var(31) = 1
triggerall = (Pos Y != [-1,-999]) && ctrl = 1
trigger1 = random <= 900
value = 131

[state -2]
type = ChangeState
triggerall =  Statetype != A && P2statetype != C && P2Movetype = A && Var(31) = 1
trigger1 = 1 && stateno = 152
value = 150

[state -2]
type = ChangeState
triggerall = Statetype = A && P2Movetype = A && ctrl = 1  && Var(31) = 1
trigger1 = random <= 900
value = 132

[state -2]
type = ChangeState
triggerall = stateno = 20  && Var(31) = 1
trigger1 = p2bodydist x <= 30 || P2movetype = A
value = 0
ctrl = 1


[state -2]
type = ChangeState
value = 412
triggerall = Var(31) = 1
triggerall = p2bodydist x = [0,10]
trigger1 = stateno = 410 && moveguarded && random < 999 




[state -2]
type = ChangeState
value = 910
triggerall = statetype = S
triggerall = Var(31) = 1
triggerall = ctrl
triggerall = p2bodydist X > 0 && p2bodydist X <= 250
triggerall = p2bodydist Y >= -80
trigger1 = p2bodydist X <= 30
trigger1 = p2movetype = A
trigger1 = (p2statetype != A && random <= 200) || (p2statetype = A && random <= 30)
trigger2 = p2movetype = A
trigger2 = p2bodydist X > 30
trigger2 = (p2statetype != A && random <= 300) || (p2statetype = A && random <= 45)
trigger3 = p2bodydist X > 200
trigger3 = (p2statetype != A && random <= 100) || (p2statetype = A && random <= 15)



[state -2]
type = ChangeState
value = 910
triggerall = statetype = S
triggerall = Var(31) = 1
triggerall = ctrl
trigger1 = enemy,numproj > 0
;trigger2 = numhelper > 0
;Esquiva


[state -2]
type = ChangeState
value = 910
triggerall = statetype = S
triggerall = stateno = 910 && time = 15
triggerall = Var(31) = 1
trigger1 = enemy,numhelper > 0



[state -2]
type = ChangeState
value = 910
triggerall = statetype = S
triggerall = stateno = 12
triggerall = Var(31) = 1
trigger1 = enemy,numhelper > 0



[state -2]
type = ChangeState
value = 910
triggerall = statetype = S
triggerall = Var(31) = 1
triggerall = ctrl
trigger1 = enemy,numhelper > 0
;trigger2 = numhelper > 0
;Esquiva

[state -2]
type = playsnd
value = 45,45
trigger1 = var(12) = 2
trigger1 = var(12) != 5
trigger1 = p2life <= 150
trigger1 = p2life != 0
;trigger1 = time = 0
channel = 6

[state -2]
type = varset
var(12) = 5
trigger1 = var(12) = 2
trigger1 = p2life <= 150
;trigger1 = time = 0
