; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Negative Edge H.Motions |----------------------------------------------
-;| CPU Activation Commands |-----------------------
[command]
name = "AI1"
command = B,D,a+c,z,c+b,s
time = 1
[command]
name = "AI2"
command = B,F,c+b,z,c+z,x,s
time = 1
[command]
name = "AI3"
command = B,U,a+b,y,c+y,s,z,D
time = 1
[command]
name = "AI4"
command = B,B,a+y,c,z+x,s
time = 1
[command]
name = "AI5"
command = B,B,a+b,z,c+b,s
time = 1
[command]
name = "AI6"
command = D,B,z+b,z,c+x,s
time = 1
[command]
name = "AI7"
command = B,U,a+b,z,c+x,s
time = 1
[command]
name = "AI8"
command = B,F,a+b,c,c+x,s
time = 1
[Command]
name = "AI9"
command = U,D,F,F,B,B,s
time = 1
[Command]
name = "AI10"
command = U,D,F,F,B,F,s
time = 1
[Command]
name = "AI11"
command = U,D,F,F,B,D,s
time = 1
[Command]
name = "AI12"
command = U,D,F,F,B,U,s
time = 1
[Command]
name = "AI13"
command = U,D,F,F,U,B,s
time = 1
[Command]
name = "AI14"
command = U,D,F,F,D,B,s
time = 1
[Command]
name = "AI15"
command = U,D,F,F,F,B,s
time = 1
[Command]
name = "AI16"
command = U,D,U,F,B,B,s
time = 1
[Command]
name = "AI17"
command = U,D,D,F,B,B,s
time = 1
[Command]
name = "AI18"
command = D,D,F,F,B,B,s
time = 1
[Command]
name = "AI19"
command = U,U,F,F,B,B,s
time = 1
[Command]
name = "AI20"
command = U,B,F,F,B,B,s
time = 1
[Command]
name = "AI21"
command = UB, U, F, a+b,s
time = 1
[Command]
name = "AI22"
command = UB, U, F, b+c,s
time = 1
[Command]
name = "AI23"
command = UB, U, F, a+c,s
time = 1
[Command]
name = "AI24"
command = UF, U, B, x+y,s
time = 1
[Command]
name = "AI25"
command = UF, U, B, y+z,s
time = 1
[Command]
name = "AI26"
command = UF, U, B, x+z,s
time = 1
[Command]
name = "AI27"
command = UB, U, F, x+y,s
time = 1
[Command]
name = "AI28"
command = UB, U, F, y+z,s
time = 1
[Command]
name = "AI29"
command = UB, U, F, x+z,s
time = 1
[Command]
name = "AI30"
command = UF, U, B, a+b,s
time = 1
[Command]
name = "AI31"
command = UF, U, B, b+c,s
time = 1
[Command]
name = "AI32"
command = UF, U, B, a+c,s
time = 1
[Command]
name = "AI33"
command = UF, DB, UB,DF ,x,s
time = 1
[Command]
name = "AI34"
command = UF, DB, UB,DF ,y,s
time = 1
[Command]
name = "AI35"
command = UF, DB, UB,DF , z,s
time = 1

[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, ~x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, ~y
time = 20

[Command]
name = "KFDrillPalm"
command = ~D, DF, F, D, DF, F, ~z
time = 20

[Command]
name = "SmashKFUpper"
command = ~F, D, DF, F, D, DF, ~x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~F, D, DF, F, D, DF, ~y
time = 30

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~F, D, DF, F, D, DF, ~z
time = 30

[Command]
name = "Dragon"
command = ~D, DB, B, D, DB, B, ~x
time = 20

[Command]
name = "Dragon"   ;Same name as above
command = ~D, DB, B, D, DB, B, ~y
time = 20

[Command]
name = "Dragon"   ;Same name as above
command = ~D, DB, B, D, DB, B, ~z
time = 20

[Command]
name = "DragonSmash"
command = ~D, DF, F, D, DF, F, ~a
time = 20

[Command]
name = "DragonSmash"   ;Same name as above
command = ~D, DF, F, D, DF, F, ~b
time = 20

[Command]
name = "DragonSmash"   ;Same name as above
command = ~D, DF, F, D, DF, F, ~c
time = 20

[Command]
name = "KneeKick"
command = ~D, DB, B, D, DB, B, ~a
time = 20

[Command]
name = "KneeKick"   ;Same name as above
command = ~D, DB, B, D, DB, B, ~b
time = 20

[Command]
name = "KneeKick"   ;Same name as above
command = ~D, DB, B, D, DB, B, ~c
time = 20

[Command]
name = "HCFx2_p"
command = ~B, DB, D, DF, F, B, DB, D, DF, F, ~x
time = 30

[Command]
name = "HCFx2_p"
command = ~B, DB, D, DF, F, B, DB, D, DF, F, ~y
time = 30

[Command]
name = "HCFx2_p"
command = ~B, DB, D, DF, F, B, DB, D, DF, F, ~z
time = 30

[Command]
name = "Murder"
command = x, x, F, a, z
time = 30

[Command]
name = "Combo"
command = ~D, DF, F, DF, D, DB, B, ~x
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, DF, D, DB, B, ~y
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, DF, D, DB, B, ~z
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, D, DB, B, ~x
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, D, DB, B, ~y
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, D, DB, B, ~z
time = 30

;-| Negative Edge S.Motions |----------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, ~x

[Command]
name = "upper_y"
command = ~F, D, DF, ~y

[Command]
name = "upper_z"
command = ~F, D, DF, ~z

[Command]
name = "fdkick_a"
command = ~F, D, DF, ~a

[Command]
name = "fdkick_b"
command = ~F, D, DF, ~b

[Command]
name = "fdkick_c"
command = ~F, D, DF, ~c

[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, ~x
time = 20

[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, ~y
time = 20

[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, ~z
time = 20

[Command]
name = "HCB_x"
command = ~F DF, D, DB, B, ~x
time = 20

[Command]
name = "HCB_y"
command = ~F DF, D, DB, B, ~y
time = 20

[Command]
name = "HCB_z"
command = ~F DF, D, DB, B, ~z
time = 20

[Command]
name = "QCF_x"
command = ~D, DF, F, ~x

[Command]
name = "QCF_y"
command = ~D, DF, F, ~y

[Command]
name = "QCF_z"
command = ~D, DF, F, ~z

[Command]
name = "QCF_k"
command = ~D, DF, F, ~a

[Command]
name = "QCF_k"
command = ~D, DF, F, ~b

[Command]
name = "QCF_k"
command = ~D, DF, F, ~c

[Command]
name = "QCF_s"
command = ~D, DF, F, ~s

[Command]
name = "QCB_x"
command = ~D, DB, B, ~x

[Command]
name = "QCB_y"
command = ~D, DB, B, ~y

[Command]
name = "QCB_z"
command = ~D, DB, B, ~z

[Command]
name = "QCB_k"
command = ~D, DB, B, ~a

[Command]
name = "QCB_k"
command = ~D, DB, B, ~b

[Command]
name = "QCB_k"
command = ~D, DB, B, ~c

[Command]
name = "FF_a"
command = F, F, ~a

[Command]
name = "FF_b"
command = F, F, ~b

[Command]
name = "FF_c"
command = F, F, ~c

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "KFDrillPalm"
command = ~D, DF, F, D, DF, F, z
time = 20

[Command]
name = "SmashKFUpper"
command = ~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~F, D, DF, F, D, DF, y
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~F, D, DF, F, D, DF, z
time = 20

[Command]
name = "Dragon"
command = ~D, DB, B, D, DB, B, x
time = 20

[Command]
name = "Dragon"   ;Same name as above
command = ~D, DB, B, D, DB, B, y
time = 20

[Command]
name = "Dragon"   ;Same name as above
command = ~D, DB, B, D, DB, B, z
time = 20

[Command]
name = "DragonSmash"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "DragonSmash"   ;Same name as above
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "DragonSmash"   ;Same name as above
command = ~D, DF, F, D, DF, F, c
time = 20

[Command]
name = "KneeKick"
command = ~D, DB, B, D, DB, B, a
time = 20

[Command]
name = "KneeKick"   ;Same name as above
command = ~D, DB, B, D, DB, B, b
time = 20

[Command]
name = "KneeKick"   ;Same name as above
command = ~D, DB, B, D, DB, B, c
time = 20

[Command]
name = "HCFx2_p"
command = ~B, DB, D, DF, F, B, DB, D, DF, F, x
time = 30

[Command]
name = "HCFx2_p"
command = ~B, DB, D, DF, F, B, DB, D, DF, F, y
time = 30

[Command]
name = "HCFx2_p"
command = ~B, DB, D, DF, F, B, DB, D, DF, F, z
time = 30

[Command]
name = "Murder"
command = x, x, F, a, z
time = 30

[Command]
name = "Combo"
command = ~D, DF, F, DF, D, DB, B, x
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, DF, D, DB, B, y
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, DF, D, DB, B, z
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, D, DB, B, x
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, D, DB, B, y
time = 30
[Command]
name = "Combo"
command = ~D, DF, F, D, DB, B, z
time = 30

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_z"
command = ~F, D, DF, z

[Command]
name = "fdkick_a"
command = ~F, D, DF, a

[Command]
name = "fdkick_b"
command = ~F, D, DF, b

[Command]
name = "fdkick_c"
command = ~F, D, DF, c

[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, x
time = 20

[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, y
time = 20

[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, z
time = 20

[Command]
name = "HCB_x"
command = ~F DF, D, DB, B, x
time = 20

[Command]
name = "HCB_y"
command = ~F DF, D, DB, B, y
time = 20

[Command]
name = "HCB_z"
command = ~F DF, D, DB, B, z
time = 20

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCF_k"
command = ~D, DF, F, a

[Command]
name = "QCF_k"
command = ~D, DF, F, b

[Command]
name = "QCF_k"
command = ~D, DF, F, c

[Command]
name = "QCF_s"
command = ~D, DF, F, s

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

[Command]
name = "QCB_k"
command = ~D, DB, B, a

[Command]
name = "QCB_k"
command = ~D, DB, B, b

[Command]
name = "QCB_k"
command = ~D, DB, B, c

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "FF_c"
command = F, F, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| Recovery |-------------------------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "fwd"
command = $F
time = 1

[Command]
name = "down"
command = $D
time = 1

[Command]
name = "back"
command = $B
time = 1

[Command]
name = "up"
command = $U
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Button |-----------------------------------------------------------
[Command]
name = "hold_x"
command = /$x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /$a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -3, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -3" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Kung Fu Combo
[State -3, Combo]
type = ChangeState
value = 4000
triggerall = Var(31) != 1
triggerall = command = "Combo"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 4000
trigger2 = movecontact

;---------------------------------------------------------------------------
;Super Flying Kick
[State -3, Super Flying Kick]
type = ChangeState
value = 3640
triggerall = PalNo = 7
triggerall = Var(31) != 1
triggerall = command = "DragonSmash"
triggerall = power >= 1000
triggerall = statetype = A
trigger1 = ctrl
trigger2 = hitdefattr = SCA, NA, SA, HA
trigger2 = movecontact
trigger2 = stateno != 3640
trigger2 = stateno != 3151
trigger2 = stateno != 3152

;---------------------------------------------------------------------------
;Art of the Dragon
[State -3, Dragon]
type = ChangeState
value = 3400
triggerall = command = "Dragon"
triggerall = power >= 1000
triggerall = Var(31) != 1
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 3400
trigger2 = movecontact

;---------------------------------------------------------------------------
;Knee Kick Super Combo
[State -3, Combo]
type = ChangeState
value = 3150
triggerall = command = "KneeKick"
triggerall = power >= 1000
triggerall = Var(31) != 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 3150
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kung Fu Murder
[State -3, Murder]
type = ChangeState
value = 3200
triggerall = command = "Murder"
triggerall = power >= 3000
triggerall = Var(31) != 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 3200
trigger2 = movecontact
trigger3 = StateNo = 230

;---------------------------------------------------------------------------
;Kung Fu Super Fireball
[State -3, Super Fireball]
type = ChangeState
value = 3300
triggerall = command = "HCFx2_p"
triggerall = power >= 1000
triggerall = Var(31) != 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 3300
trigger2 = movecontact
trigger3 = StateNo = 230

;---------------------------------------------------------------------------
;Kung Fu Drill Palm
[State -3, Kung Fu Drill Palm]
type = ChangeState
value = 3010
triggerall = command = "KFDrillPalm"
triggerall = power >= 1000
triggerall = Var(31) != 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 3010
trigger2 = movecontact

;---------------------------------------------------------------------------
;Dragon Smash
[State -3, Dragon Smash]
type = ChangeState
value = 3100
triggerall = command = "DragonSmash"
triggerall = power >= 1000
triggerall = Var(31) != 1
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 3100
trigger2 = movecontact

;---------------------------------------------------------------------------
;Smash Kung Fu Upper (uses one super bar)
;X}bVEJt[EEbp[iQ[WxPj
[State -3, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = command = "SmashKFUpper"
triggerall = power >= 1000
triggerall = Var(31) != 1
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -3, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = command = "TripleKFPalm"
triggerall = power >= 1000
triggerall = Var(31) != 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -3, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -3, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
triggerall = Var(31) != 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
; Counter
[State -3, Counter]
type = ChangeState
value = 900
triggerall = Var(31) != 1
triggerall = power >= 1000
triggerall = command = "x" && command = "y" || command = "y" && command = "z" || command = "x" && command = "z" || command = "x" && command = "y" && command = "z"
triggerall = statetype != A
trigger1 = stateno = 150
trigger2 = stateno = 151
trigger3 = stateno = 152
trigger4 = stateno = 153

;---------------------------------------------------------------------------
;Flying Dragon Kick
[State -3, Fast Kung Fu Upper]
type = ChangeState
value = 1600
triggerall = Var(31) != 1
triggerall = command = "fdkick_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Flying Dragon Kick
[State -3, Fast Kung Fu Upper]
type = ChangeState
value = 1610
triggerall = Var(31) != 1
triggerall = command = "fdkick_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Flying Dragon Kick
[State -3, Fast Kung Fu Upper]
type = ChangeState
value = 1620
triggerall = Var(31) != 1
triggerall = command = "fdkick_c"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Hadoken
[State -3, Light Hadoken]
type = ChangeState
value = 1500
triggerall = Var(31) != 1
triggerall = command = "HCF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Medium Hadoken
[State -3, Medium Hadoken]
type = ChangeState
value = 1510
triggerall = Var(31) != 1
triggerall = command = "HCF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Hadoken
[State -3, Strong Hadoken]
type = ChangeState
value = 1520
triggerall = Var(31) != 1
triggerall = command = "HCF_z"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Knee
;Jt[RiQ[WxP^Rj
[State -3, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = Var(31) != 1
triggerall = command = "FF_c"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Knee
;Jt[Rij
[State -3, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = Var(31) != 1
triggerall = command = "FF_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Knee
;Jt[Rij
[State -3, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = Var(31) != 1
triggerall = command = "FF_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Blow
[State -3, Fast Kung Fu Blow]
type = ChangeState
value = 1220
triggerall = Var(31) != 1
triggerall = command = "QCB_z"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Blow
[State -3, Light Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = Var(31) != 1
triggerall = command = "QCB_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -3, Strong Kung Fu Blow]
type = ChangeState
value = 1210
triggerall = Var(31) != 1
triggerall = command = "QCB_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Palm
;Jt[˂iQ[WxP^Rj
[State -3, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = Var(31) != 1
triggerall = command = "QCF_z"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -3, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = Var(31) != 1
triggerall = command = "QCF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
;Jt[˂ij
[State -3, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = Var(31) != 1
triggerall = command = "QCF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Upper
;Jt[EEbp[
[State -3, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = Var(31) != 1
triggerall = command = "upper_z"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Upper
;Jt[EEbp[ij
[State -3, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = Var(31) != 1
triggerall = command = "upper_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Upper
;Jt[EEbp[ij
[State -3, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = Var(31) != 1
triggerall = command = "upper_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
; Power Charge
[State -3, Power Charge]
type = ChangeState
value = 1900
triggerall = Var(31) != 1
triggerall = Power < 3000
triggerall = command = "hold_y"
triggerall = command = "hold_b"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -3, Run Fwd]
type = ChangeState
value = 100
triggerall = Var(31) != 1
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -3, Run Back]
type = ChangeState
value = 105
triggerall = Var(31) != 1
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Recovery Roll Backward
[State -3, Roll_back]
type = ChangeState
value = 5220
triggerall = Var(31) != 1
triggerall = alive
triggerall = stateno != 5120
triggerall = stateno != 5291
triggerall = command = "holdback"
triggerall = command = "recovery"
trigger1 = statetype = L

; Recovery Roll Forward
[State -3, Roll_fwd]
type = ChangeState
value = 5230
triggerall = Var(31) != 1
triggerall = alive
triggerall = stateno != 5120
triggerall = stateno != 5291
triggerall = command = "holdfwd"
triggerall = command = "recovery"
trigger1 = statetype = L

;---------------------------------------------------------------------------
; Roll Backward
[State -3, Roll_back]
type = ChangeState
value = 5220
triggerall = Var(31) != 1
triggerall = command = "QCB_k"
triggerall = statetype != A
trigger1 = ctrl

; Roll Forward
[State -3, Roll_fwd]
type = ChangeState
value = 5230
triggerall = Var(31) != 1
triggerall = command = "QCF_k"
triggerall = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -3, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = Var(31) != 1
triggerall = command = "y" || command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Throw
;
[State -3, Kung Fu Throw]
type = ChangeState
value = 850
triggerall = Var(31) != 1
triggerall = command = "b" || command = "c"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;-p`
[State -3, Stand Light Punch]
type = ChangeState
value = 200
triggerall = Var(31) != 1
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;Stand Light Punch
;-p`
;[State -3, Stand Light Punch]
;type = ChangeState
;value = 444100
;triggerall = Var(31) != 1
;triggerall = command = "start"
;triggerall = command != "holddown"
;trigger1 = statetype = S
;trigger1 = ctrl
;trigger2 = stateno = 200
;trigger2 = time > 6


;---------------------------------------------------------------------------
;Stand Medium Punch
;p`
[State -3, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = Var(31) != 1
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -3, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = Var(31) != 1
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -3, Stand Light Kick]
type = ChangeState
value = 230
triggerall = Var(31) != 1
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Standing Medium Kick
;LbN
[State -3, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = Var(31) != 1
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Standing Strong Kick
;-LbN
[State -3, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = Var(31) != 1
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Taunt
;
[State -3, Taunt]
type = ChangeState
value = 195
triggerall = Var(31) != 1
triggerall = command = "start"
triggerall = command != "QCF_s"
trigger1 = statetype != A
trigger1 = ctrl

; Roll Forward Taunt
[State -3, Roll_fwd]
type = ChangeState
value = 196
triggerall = Var(31) != 1
triggerall = command = "QCF_s"
triggerall = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -3, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = Var(31) != 1
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Medium Punch
;Ⴊ݋p`
[State -3, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = Var(31) != 1
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -3, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = Var(31) != 1
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -3, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = Var(31) != 1
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Medium Kick
;ႪݎLbN
[State -3, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = Var(31) != 1
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -3, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = Var(31) != 1
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -3, Jump Light Punch]
type = ChangeState
value = 600
triggerall = Var(31) != 1
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
;Jump Medium Punch
;󒆎p`
[State -3, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = Var(31) != 1
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -3, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = Var(31) != 1
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -3, Jump Light Kick]
type = ChangeState
value = 630
triggerall = Var(31) != 1
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -3, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = Var(31) != 1
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -3, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = Var(31) != 1
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact


;===========================================================================
;---------------------------------------------------------------------------
;Artificial Inteligence
;---------------------------------------------------------------------------
[State -3, 0]  ;ai start
type = varset
triggerall = var(55) = 0
trigger1 = command = "AI1"
trigger2 = command = "AI2"
trigger3 = command = "AI3"
trigger4 = command = "AI4"
trigger5 = command = "AI5"
trigger6 = command = "AI6"
trigger7 = command = "AI7"
trigger8 = command = "AI8"
trigger9 = command = "AI9"
trigger10 = command = "AI10"
trigger11 = command = "AI11"
trigger12 = command = "AI12"
trigger13 = command = "AI13"
trigger14 = command = "AI14"
trigger15 = command = "AI15"
trigger16 = command = "AI16"
trigger17 = command = "AI17"
trigger18 = command = "AI18"
trigger19 = command = "AI19"
trigger20 = command = "AI20"
trigger21 = command = "AI21"
trigger22 = command = "AI22"
trigger23 = command = "AI23"
trigger24 = command = "AI24"
trigger25 = command = "AI25"
trigger26 = command = "AI26"
trigger27 = command = "AI27"
trigger28 = command = "AI28"
trigger29 = command = "AI29"
trigger30 = command = "AI30"
trigger31 = command = "AI31"
trigger32 = command = "AI32"
trigger33 = command = "AI33"
trigger34 = command = "AI34"
trigger35 = command = "AI35"
var(31) = 1



;====================================
;AI Light Punch
[State -3]
type = ChangeState
value = 444240;555200
triggerall = Var(31) = 1
triggerall = StateType = S
triggerall = p2StateType = S && P2StateType != A && P2StateType != C
triggerall = roundstate = 2
triggerall = stateno < 800 
trigger1 = P2BodyDist X = [25,35]
trigger1 = ctrl = 1
;===================================
;AI Light Kick
[State -3]
type = ChangeState
value = 230
triggerall = Var(31) = 1 && random > life && time % 4 
triggerall = Life != 0
triggerall = p2bodydist X <= 40
triggerall = roundstate = 2
triggerall = ctrl
triggerall = StateType != A && MoveType != H
triggerall = p2stateno = [5050,5110]
trigger1 = enemy, numproj = 0
trigger2 = p2movetype != A
;===================================
;AI Heavy Punch
[State -3]
type = changestate
value = 210
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H 
triggerall = ctrl && p2life!= 0
triggerall = P2BodyDist X = [00,25]
triggerall = P2StateType != A
triggerall = enemy, numproj = 0
triggerall = p2stateno = [5000,5999]
trigger1 = 1
trigger2 = p2stateno = 1006
trigger2 = time >= 15
;=========================
;AI Crouch Heavy Punch
[State -3]
type = changestate
value = 444240;444410
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H 
triggerall = ctrl && p2life!= 0
triggerall = P2BodyDist X = [-10,30]
triggerall = P2BodyDist Y = [-30,-1]
triggerall = p2StateType = A
trigger1 = p2stateno = [5000,5999]
trigger2 = 1
trigger3 = p2stateno = 1006
trigger3 = time >= 15
;======================
;AI Crouch Heavy Punch
[State -3]
type = changestate
value = 444240;5551000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H 
triggerall = ctrl && p2life!= 0
triggerall = stateno != 3050
triggerall = stateno != 3000
triggerall = P2BodyDist X = [-2,29]
triggerall = P2BodyDist Y = [-60,-1]
triggerall = p2StateType = A
trigger1 = p2stateno = [5000,5999]
trigger2 = 1
trigger3 = p2stateno = 1006
trigger3 = time >= 15

;AI Crouch Heavy Punch
[State -3]
type = changestate
value = 444240;4441000
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A 
triggerall = Stateno != 150
triggerall = Stateno != 151
triggerall = stateno != 3050
triggerall = stateno != 3000
triggerall = ctrl && p2life!= 0
triggerall = P2BodyDist X = [-40,29]
trigger1 = p2stateno = [5000,5999]
trigger2 = 1
trigger3 = p2stateno = 1006
trigger3 = time >= 15
;=============
;AI AIR Light Punch
[State -3]
type = ChangeState
value = 630
triggerall = (roundstate != [0,1]) || (roundstate != [3,4])
triggerall = Var(31) = 1 
triggerall = StateType = A && MoveType != H 
triggerall = ctrl && p2life!= 0
trigger1 = P2BodyDist X = [-5,30]
trigger1 = P2BodyDist Y = [-10,10]
trigger1 = p2MoveType = H
;===================================
;      AI HYPER ATTACKS 
;===================================
; Gamma Crush
[State -3]
type = changestate
value = 1200; + (power >= 2000)*50
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && random > life && time % 4 
triggerall = StateType != A && MoveType != H
triggerall = p2life!= 0
triggerall = random > life && time % 4 
triggerall = ctrl && P2movetype = A  
triggerall = P2BodyDist X = [-50,50] 
triggerall = P2BodyDist Y >= -150
trigger1 = p2stateno = 50
trigger2 = p2stateno = [5050,5070]
trigger3 = p2stateno = [5100,5102]
trigger4 = p2stateno = 5110
trigger5 = p2stateno = 5200
trigger6 = 1
trigger7 = enemy, numproj >= 0
trigger8 = stateno < 800 && random >=501
;===================================
;Hyper Gamma Charge Vertical
[State -3]
type = changestate
value = 3150 ;+ (power >= 2000)*50
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && random > life && time % 4 
triggerall = StateType != A && MoveType != H && power >= 1000
triggerall = ctrl && P2movetype = A  && stateno < 800 && random <=500
triggerall = P2BodyDist X = [-50,50] 
triggerall = P2BodyDist Y >= -120
triggerall = p2life!= 0
trigger1 = p2stateno = 50
trigger2 = p2stateno = [5050,5070]
trigger3 = p2stateno = [5100,5102]
trigger4 = p2stateno = 5110
trigger5 = p2stateno = 5200
trigger6 = 1
trigger7 = enemy, numproj >= 0
;===================================
;===================================
;      AI SUPER ATTACKS 
;===================================
;AI Chiropractor
[State -3]
type = changestate
value = 630;1125
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType != A && MoveType != H && p2life!= 0
triggerall = ctrl
triggerall = P2BodyDist X = [10,60]
triggerall = P2BodyDist Y <= -20
triggerall = p2movetype != H
trigger1 = p2movetype = A
trigger1 = random < 989
trigger2 = p2statetype = A
trigger2 = random < 989
;===================================
;AI Diving Hulk
[State -3]
type = changestate
value = 630;1150
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && stateno < 800
triggerall = StateType = A && MoveType != H && p2life!= 0
triggerall = ctrl
triggerall = P2BodyDist X = [0,20]
triggerall = P2BodyDist Y >= -100
trigger1 = p2MoveType = A
trigger1 = random >= 50
trigger2 = enemy, Numproj > 0 && random >= 10
trigger3 = enemy, Numhelper > 0 && random >= 10
trigger4 = p2stateno = [5000,5999]




;AI Gamma Charge
[State -3]
type = changestate
value = 1120
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 ;&& p2life!= 0 && Random >= 450
triggerall = statetype != A
triggerall = ctrl
triggerall = P2BodyDist X = [10,150]
trigger1 = p2movetype = A
trigger1 = random >= 50
;trigger2 = enemy, Numproj > 0
;trigger3 = enemy, Numhelper > 0

;evilryu
[State -3]
type = changestate
value = 1020
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && p2life!= 0 && Random >= 450
triggerall = statetype != A
triggerall = ctrl
triggerall = p2name = "Evil Ryu"
triggerall = P2BodyDist X = [10,150]
triggerall = P2stateno = 1862
trigger1 = p2movetype = A
trigger1 = random >= 50
trigger2 = enemy, Numproj > 0
trigger3 = enemy, Numhelper > 0
;===================================
;AI Gamma Wave
[State -3]
type = changestate
value = 5230
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 
triggerall = statetype != A
triggerall = ctrl
triggerall = P2BodyDist X >= 46
triggerall = p2movetype = A
trigger1 = random >= 50
trigger2 = enemy, Numproj > 0
trigger3 = enemy, Numhelper > 0
;===================================
;AI Gamma Charge Vertical
[State -3]
type = changestate
value = 5230
triggerall = (roundstate != [0,1]) || (roundstate != [3,4]) 
triggerall = Var(31) = 1 && power <= 1000 && p2life!= 0
triggerall = statetype != A
triggerall = ctrl
triggerall = P2BodyDist X = [-80,80] 
triggerall = P2statetype = A
trigger1 = p2movetype = A
trigger2 = enemy, Numproj > 0 && random >= 10
trigger3 = enemy, Numhelper > 0 && random >= 10
;===================================
;====================================
;===================================
;====================================
;===================================
;AI Ground Throw
[State -3]
type = ChangeState
value = 444240
triggerall = Var(31) = 1 
triggerall = Life != 0 && stateno < 600
triggerall = p2bodydist X <= 15
triggerall = roundstate = 2 && ctrl = 1
triggerall = StateType != A && MoveType != H
triggerall = p2statetype != A
triggerall = p2statetype != L
triggerall = random <= 400
triggerall = p2stateno != [5000,5999]
triggerall = movetype != H 
trigger1 = enemy, numproj = 0
trigger2 = p2movetype != A

;AI Ground Throw
[State -3]
type = ChangeState
value = 444240
triggerall = Var(31) = 1 && random > life && time % 4 
triggerall = Life != 0 && stateno < 600
triggerall = p2bodydist X <= 35
triggerall = roundstate = 2 && ctrl = 1
triggerall = StateType != A && MoveType != H
triggerall = p2statetype != A
triggerall = p2statetype != L
triggerall = p2stateno != [5000,5999]
triggerall = movetype != H 
trigger1 = enemy, numproj = 0
trigger2 = p2movetype = A
;===================================
;===================================
;===================================
;AI Gamma Pound
[State -3]
type = ChangeState
value = 1520
triggerall = Var(31) = 1 && random > life && time % 4 
triggerall = Life != 0 && stateno < 600
triggerall = p2bodydist X = [145,206]
triggerall = roundstate = 2 && ctrl = 1
triggerall = StateType != A && MoveType != H
triggerall = P2MoveType != H
triggerall = P2StateNo != 40
triggerall = StateNo != 195
triggerall = p2statetype != A
triggerall = p2stateno != [5000,5999]
triggerall = movetype != H 
triggerall = random > 500
trigger1 = enemy, numproj = 0
trigger2 = p2movetype != A
;===================================
;AI Alpha Counter Charge
[State -3]
type = ChangeState
value = 900
triggerall = Var(31) = 1
triggerall = StateType != A && StateType != L
triggerall = P2life != 0
trigger1 = P2BodyDist x <= 100
trigger1 = StateNo = [150,153]
;trigger1 = Random = [0,500]

;AI Alpha Counter Charge
[State -3]
type = ChangeState
value = 630
triggerall = Var(31) = 1 
triggerall = StateType = A && StateType != L
triggerall = P2life != 0
trigger1 = P2BodyDist x <= 100
trigger1 = StateNo = [150,155]
;trigger1 = Random = [0,500]



;[State -3, AI Jump2]
;type = ChangeState
;value = 40;ifelse(random <= 400,430,400)
;triggerall = Var(31) = 1 && random > life && time % 4 
;triggerall = P2statetype = C
;triggerall = statetype != A
;triggerall = p2stateno != [5020,5999]
;triggerall = stateno != [902,904]
;trigger1 = p2bodydist x <= 20; p2 is close enough for stand light punch
;trigger1 = p2bodydist y = [-5,10]
;trigger1 = ctrl  && random <=300
;;trigger2 = ctrl
;;trigger2 = p2bodydist x = [-22,13]
;;trigger2 = p2bodydist y = [-14,-10]

;[State -3, AI If defended]
;type = ChangeState
;value = 88840
;triggerall = Var(31) = 1
;triggerall = statetype != A
;triggerall = random <= 499
;trigger1 = stateno = 4441050 &&  moveguarded
;trigger2 = stateno = 1055 &&  movecontact ;&& p2bodydist x > 2
;trigger3 = stateno = 1050 &&  movecontact; && p2bodydist X > 10

;AI Gamma Pound
[State -3]
type = ChangeState
value = 444100;4441000
triggerall = StateType != A
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno < 800 
triggerall = movehit
triggerall = random <= 332
trigger1 = P2BodyDist X = [-5,60]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [-5,60]
;trigger2 = prevstateno = 300

;AI Gamma Pound
[State -3]
type = ChangeState
value = 444100;4441000 
triggerall = StateType = S
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno <= 1 
triggerall = moveguarded
trigger1 = P2BodyDist X = [5,55]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [5,55]
;trigger2 = prevstateno = 200

;AI Gamma Pound
[State -3]
type = ChangeState
value = 444100;5551000
triggerall = StateType != A
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno < 600 
triggerall = random <= 299
triggerall = movehit
trigger1 = P2BodyDist X = [-5,60]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [-5,60]
;trigger2 = prevstateno = 200


;AI Gamma Pound
[State -3]
type = ChangeState
value = 444100;7771000
triggerall = StateType != A
triggerall = Var(31) = 1
triggerall = P2StateType != A
triggerall = roundstate = 2
triggerall = stateno < 800 
triggerall = movehit
trigger1 = P2BodyDist X = [-5,60]
;trigger1 = prevstateno = 410
trigger2 = P2BodyDist X = [-5,60]
;trigger2 = prevstateno = 200



[State -3, AI Run Fwd]
type = ChangeState
value = 100
triggerall = Movetype != A && stateno != 100 && P2Movetype != A && ctrl && Var(31) = 1
triggerall = pos y = 0
trigger1 = (p2stateno = 5120 || p2stateno = 5100 || p2stateno = 5050 || p2statetype = S) && p2bodydist x >= 100
trigger1 = p2movetype != A && random < 300 && statetype != A
trigger2 = ProjGuardedTime(221) >= 1
trigger2 = ctrl && random < 999

[State -3, AI Run Fwd Stop]
type = ChangeState
triggerall = stateno = 100 &&  Var(31) = 1
trigger1 = P2movetype != I && p2movetype != H
trigger1 = p2bodydist x < 2 
value = 0
ctrl = 1


[State -3, AI Standing Guard]
type = ChangeState
triggerall =  Statetype != A && P2statetype != C && Statetype = S && P2Movetype = A && var(20) = 20
triggerall = (Pos Y != [-1,-999]) && ctrl = 1
trigger1 = random <= 900
value = 130 

[State -3, AI Stand to Crouch Guard Transition]
type = ChangeState
triggerall = StateType != A && P2statetype = C && P2Movetype = A && Var(31) = 1
triggerall = Pos Y != [-1,-999]
trigger1 = 1 &&  stateno = 150
value = 152

[State -3, AI Crouching Guard]
type = ChangeState
triggerall = StateType != A && P2statetype = C && P2Movetype = A && Var(31) = 1
triggerall = (Pos Y != [-1,-999]) && ctrl = 1
trigger1 = random <= 900
value = 131

[State -3, AI Crouch to Stand Guard Transition]
type = ChangeState
triggerall =  Statetype != A && P2statetype != C && P2Movetype = A && Var(31) = 1
trigger1 = 1 && stateno = 152
value = 150

[State -3,AI Aerial Guard]
type = ChangeState
triggerall = Statetype = A && P2Movetype = A && ctrl = 1  && Var(31) = 1
trigger1 = random <= 900
value = 132

[State -3, AI Walk Fwd Stop]
type = ChangeState
triggerall = stateno = 20  && Var(31) = 1
trigger1 = p2bodydist x <= 30 || P2movetype = A
value = 0
ctrl = 1

;[State -3, AI Crouch Light Punch]
;type = ChangeState
;value = 400
;triggerall = Var(31) = 1 && P2MoveType != A
;trigger1 = (p2bodydist y = [-5,5]) && statetype = S && ctrl && random < 999 && p2bodydist x = 5
;trigger2 = stateno = 200 && moveguarded && pos y = 0 && random < 700
;trigger3 = var(34) = 19

;[State -3,AI Crouch Weak Kick]
;type = ChangeState
;value = 430
;triggerall = Var(31) = 1
;triggerall = p2bodydist x = [0,49]
;trigger1 = stateno = 400 && movecontact && random < 999 
;trigger2 = stateno = 1031 && moveguarded
;trigger3 = stateno = 201 && moveguarded
;trigger4 = (stateno = 200 || stateno = 230) && moveguarded && pos y = 0 && random < 800
;trigger5 = p2statetype != A && p2bodydist x <= 50 && p2statetype = S && statetype != A && ctrl
;trigger6 = var(34) = 20

[State -3,AI Crouch Strong Kick]
type = ChangeState
value = 450
triggerall = Var(31) = 1
triggerall = p2bodydist x = [0,10]
trigger1 = stateno = 410 && moveguarded && random < 999 



;Esquiva
[State -3, Dodge]
type = ChangeState
value = 5230
triggerall = p2statetype != L
triggerall = statetype = S
triggerall = Var(31) = 1
triggerall = ctrl
triggerall = p2bodydist X >= 0 && p2bodydist X <= 250
triggerall = p2bodydist Y >= -80
trigger1 = p2bodydist X <= 30
trigger1 = p2movetype = A
trigger1 = (p2statetype != A && random <= 200) || (p2statetype = A && random <= 30)
trigger2 = p2movetype = A
trigger2 = p2bodydist X > 30
trigger2 = (p2statetype != A && random <= 300) || (p2statetype = A && random <= 45)
trigger3 = p2bodydist X > 200
trigger3 = (p2statetype != A && random <= 100) || (p2statetype = A && random <= 15)



