; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;
[Command]
name = "Ankoku-AsurA-TaG"
command = s
time = 1
[Command]
name =  "AsuAtras"
command = B
time = 1
[Command]
name =  "AsuAdelante"
command = F
time = 1
[Command]
name =  "AsuAbajo"
command = D
time = 1
[Command]
name =  "AsuArriba"
command = U
time = 1
[command]
name = "AI1"
command = B,D,a+c,z,c+b,s
time = 1
[command]
name = "AI2"
command = B,F,c+b,z,c+z,x,s
time = 1
[command]
name = "AI3"
command = B,U,a+b,y,c+y,s,z,D
time = 1
[command]
name = "AI4"
command = B,B,a+y,c,z+x,s
time = 1
[command]
name = "AI5"
command = B,B,a+b,z,c+b,s
time = 1
[command]
name = "AI6"
command = D,B,z+b,z,c+x,s
time = 1
[command]
name = "AI7"
command = B,U,a+b,z,c+x,s
time = 1
[command]
name = "AI8"
command = B,F,a+b,c,c+x,s
time = 1
[Command]
name = "AI9"
command = U,D,F,F,B,B,s
time = 1
[Command]
name = "AI10"
command = U,D,F,F,B,F,s
time = 1
[Command]
name = "AI11"
command = U,D,F,F,B,D,s
time = 1
[Command]
name = "AI12"
command = U,D,F,F,B,U,s
time = 1
[Command]
name = "AI13"
command = U,D,F,F,U,B,s
time = 1
[Command]
name = "AI14"
command = U,D,F,F,D,B,s
time = 1
[Command]
name = "AI15"
command = U,D,F,F,F,B,s
time = 1
[Command]
name = "AI16"
command = U,D,U,F,B,B,s
time = 1
[Command]
name = "AI17"
command = U,D,D,F,B,B,s
time = 1
[Command]
name = "AI18"
command = D,D,F,F,B,B,s
time = 1
[Command]
name = "AI19"
command = U,U,F,F,B,B,s
time = 1
[Command]
name = "AI20"
command = U,B,F,F,B,B,s
time = 1
[Command]
name = "AI21"
command = UB, U, F, a+b,s
time = 1
[Command]
name = "AI22"
command = UB, U, F, b+c,s
time = 1
[Command]
name = "AI23"
command = UB, U, F, a+c,s
time = 1
[Command]
name = "AI24"
command = UF, U, B, x+y,s
time = 1
[Command]
name = "AI25"
command = UF, U, B, y+z,s
time = 1
[Command]
name = "AI26"
command = UF, U, B, x+z,s
time = 1
[Command]
name = "AI27"
command = UB, U, F, x+y,s
time = 1
[Command]
name = "AI28"
command = UB, U, F, y+z,s
time = 1
[Command]
name = "AI29"
command = UB, U, F, x+z,s
time = 1
[Command]
name = "AI30"
command = UF, U, B, a+b,s
time = 1
[Command]
name = "AI31"
command = UF, U, B, b+c,s
time = 1
[Command]
name = "AI32"
command = UF, U, B, a+c,s
time = 1
[Command]
name = "AI33"
command = UF, DB, UB,DF ,x,s
time = 1
[Command]
name = "AI34"
command = UF, DB, UB,DF ,y,s
time = 1
[Command]
name = "AI35"
command = UF, DB, UB,DF , z,s
time = 1

[Command] ;Two quarter circles forward + y
name = "Ult"
command = ~D, DF, F, D, DF, F, c+z
time = 30

[Command] ;Two quarter circles forward + y
name = "Ult"
command = ~D, DF, F, D, DF, F, c+z
time = 30

[Command] ;Two quarter circles forward + y
name = "Ult"
command = ~D, DF, F, DF, D, DF, F, c+z
time = 30

[Command] ;Two quarter circles forward + y
name = "2QCF_x"
command = ~D, DF, F, D, DF, F, x
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_x"
command = ~D, DF, F, D, DF, F, y
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_x"
command = ~D, DF, F, D, DF, F, z
time = 25

[Command] ;Two quarter circles forward + y
name = "Ult1"
command = ~D, DB, B, D, DB, B, x
time = 25

[Command] ;Two quarter circles forward + y
name = "Ult1"
command = ~D, DB, B, D, DB, B, y
time = 25

[Command] ;Two quarter circles forward + y
name = "Ult1"
command = ~D, DB, B, D, DB, B, z
time = 25

[Command] ;Two quarter circles forward + y
name = "Ult2"
command = ~D, DB, B, D, DB, B, a
time = 25

[Command] ;Two quarter circles forward + y
name = "Ult2"
command = ~D, DB, B, D, DB, B, b
time = 25

[Command] ;Two quarter circles forward + y
name = "Ult2"
command = ~D, DB, B, D, DB, B, c
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_a"
command = ~D, DF, F, D, DF, F, a
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_a"
command = ~D, DF, F, D, DF, F, b
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_a"
command = ~D, DF, F, D, DF, F, c
time = 25
[Command]
name = "QCFp_EX"
command = ~D, DF, F, x+y

[Command]
name = "QCFp_EX"
command = ~D, DF, F, y+z

[Command]
name = "QCFp_EX"
command = ~D, DF, F, x+z

[Command]
name = "DPp_EX"
command = ~F, D, DF, x+y

[Command]
name = "DPp_EX"
command = ~F, D, DF, y+z

[Command]
name = "DPp_EX"
command = ~F, D, DF, x+z

[Command]
name = "QCBp_EX"
command = ~D, DB, B, x+y

[Command]
name = "QCBp_EX"
command = ~D, DB, B, y+z

[Command]
name = "QCBp_EX"
command = ~D, DB, B, x+z

[Command]
name = "QCFk_EX"
command = ~D, DF, F, a+b

[Command]
name = "QCFk_EX"
command = ~D, DF, F, a+c

[Command]
name = "QCFk_EX"
command = ~D, DF, F, b+c

[Command]
name = "QCBk_EX"
command = ~D, DB, B, a+b

[Command]
name = "QCBk_EX"
command = ~D, DB, B, a+c

[Command]
name = "QCBk_EX"
command = ~D, DB, B, b+c
[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

[Command]
name = "DP_x"
command = ~F, D, DF, x

[Command]
name = "DP_y"
command = ~F, D, DF, y

[Command]
name = "DP_z"
command = ~F, D, DF, z

[Command]
name = "DP_a"
command = ~F, D, DF, a

[Command]
name = "DP_b"
command = ~F, D, DF, b

[Command]
name = "DP_c"
command = ~F, D, DF, c

[Command]
name = "RDP_x"
command = ~B, D, DB, x

[Command]
name = "RDP_y"
command = ~B, D, DB, y

[Command]
name = "RDP_z"
command = ~B, D, DB, z

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1



;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "hparry"
command = F
time = 1

[Command]
name = "lparry"
command = D
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdc";Required (do not remove)
command = /c
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.

[Statedef -1]

; Tetsu Thrasher
[State -1]
type = ChangeState
value = 4000
TriggerAll = var(31) != 1
triggerall = power = 3000
triggerall = command = "Ult"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact



; Shoryureppa
[State -1]
type = ChangeState
value = 3000
TriggerAll = var(31) != 1
triggerall = stateno !=3000
triggerall = power >= 1000
triggerall = command = "2QCF_a"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA, HA 
trigger2 = movecontact
trigger3 = NumHelper = 1
trigger3 = helper, movecontact 


; Typhoon Kick
[State -1]
type = ChangeState
value = ifelse(statetype = A,3045,3040)
TriggerAll = var(31) != 1
triggerall = stateno !=[3040,3047]
triggerall = power >= 1000
triggerall = command = "Ult2"
trigger1 = ctrl = 1
trigger2 = hitdefattr = SCA, NA, SA, HA 
trigger2 = movecontact
trigger3 = NumHelper = 1
trigger3 = helper, movecontact 

[State -1]
type = ChangeState
value = 3090
TriggerAll = var(31) != 1
triggerall = stateno !=[3090,3093]
triggerall = power >= 1000
triggerall = command = "2QCF_a" 
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = hitdefattr = A, NA, SA, HA
trigger2 = movecontact
trigger3 = NumHelper = 1
trigger3 = helper, movecontact 

; Fatal Lightning
[State -1]
type = ChangeState
value = 3080
TriggerAll = var(31) != 1
triggerall = stateno !=3080
triggerall = power >= 1000
triggerall = command = "Ult1"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = hitdefattr = A, NA, SA, HA
trigger2 = movecontact
trigger3 = NumHelper = 1
trigger3 = helper, movecontact 

; Shinkuu Hadoken
[State -1]
type = ChangeState
value = ifelse(statetype=A,3070,3010)
TriggerAll = var(31) != 1
triggerall = stateno !=3070 && stateno !=3010
triggerall = power >= 1000
triggerall = command = "2QCF_x" 
trigger1 = ctrl = 1
trigger2 = hitdefattr = SCA, NA, SA, HA
trigger2 = movecontact
trigger3 = NumHelper = 1
trigger3 = helper, movecontact

; Final Bomber
[State -1]
type = ChangeState
value = 3050
TriggerAll = var(31) != 1
triggerall = stateno !=[3050,3055] 
triggerall = power >= 1000
triggerall = command = "Ult1"
triggerall = statetype !=A 
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, HA
trigger2 = movecontact
trigger3 = NumHelper = 1
trigger3 = helper, movecontact 

;Dragon Punch_EX
[State -1]
type = ChangeState
value = 2020
TriggerAll = var(31) != 1
triggerall = power >= 500
triggerall = command = "DPp_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2000
TriggerAll = var(31) != 1
triggerall = !NumHelper(11000)
triggerall = power >= 500
triggerall = command = "QCFp_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Cyclone Kick_EX
[State -1]
type = ChangeState
value = ifelse(statetype =A,2080,2010)
TriggerAll = var(31) != 1
triggerall = power >= 500
triggerall = command = "QCBk_EX"
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [600,699])
trigger2 = movecontact

;Cyclone Kick_EX
[State -1]
type = ChangeState
value = 2070
TriggerAll = var(31) != 1
triggerall = power >= 500
triggerall = command = "QCBp_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Cyclone Kick_EX
[State -1]
type = ChangeState
value = 2090
TriggerAll = var(31) != 1
triggerall = power >= 500
triggerall = command = "QCFk_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 1068
TriggerAll = var(31) != 1
triggerall = !NumHelper(11000)
triggerall = power >= 500
triggerall = command = "QCFp_EX"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699])  
trigger2 = movecontact

;Dive Kick_EX
[State -1]
type = ChangeState
value = 2030
TriggerAll = var(31) != 1
triggerall = power >= 500
triggerall = command = "QCFk_EX"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699])  
trigger2 = movecontact

;Neo Recovery
[State -1]
type = ChangeState
value = 910
TriggerAll = var(31) != 1
triggerall = power = 3000 && CanRecover = 0
triggerall = command = "QCFp_EX"
triggerall = life > 0
trigger1 = stateno = 5050

;Kikkoken_X
[State -1]
type = ChangeState
value = 1020
TriggerAll = var(31) != 1
triggerall = command = "DP_x"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1022
TriggerAll = var(31) != 1
triggerall = command = "DP_y"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1024
TriggerAll = var(31) != 1
triggerall = command = "DP_z"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Kikkoken_X
[State -1]
type = ChangeState
value = 1040
TriggerAll = var(31) != 1
triggerall = command = "DP_a"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1041
TriggerAll = var(31) != 1
triggerall = command = "DP_b"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1042
TriggerAll = var(31) != 1
triggerall = command = "DP_c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Kikkoken_X
[State -1]
type = ChangeState
value = 1000
TriggerAll = var(31) != 1
triggerall = !NumHelper(11000)
triggerall = command = "QCF_x"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1001
TriggerAll = var(31) != 1
triggerall =!NumHelper(11000)
triggerall = command = "QCF_y"
triggerall = numproj = 0
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1002
TriggerAll = var(31) != 1
triggerall = !NumHelper(11000)
triggerall = numproj = 0
triggerall = command = "QCF_z"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Kikkoken_X
[State -1]
type = ChangeState
value = 1060
TriggerAll = var(31) != 1
triggerall = !NumHelper(11000)
triggerall = command = "QCF_x"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1061
TriggerAll = var(31) != 1
triggerall =!NumHelper(11000)
triggerall = command = "QCF_y"
triggerall = numproj = 0
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699])  
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1062
TriggerAll = var(31) != 1
triggerall = !NumHelper(11000)
triggerall = numproj = 0
triggerall = command = "QCF_z"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699])  
trigger2 = movecontact


;Kikkoken_X
[State -1]
type = ChangeState
value = ifelse(statetype = A,1082,1010)
TriggerAll = var(31) != 1
triggerall = command = "QCB_a"
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [600,699]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = ifelse(statetype = A,1083,1012)
TriggerAll = var(31) != 1
triggerall = command = "QCB_b"
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [600,699])
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = ifelse(statetype = A,1084,1014)
TriggerAll = var(31) != 1
triggerall = command = "QCB_c"
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [600,699])
trigger2 = movecontact

;Tetsu Rave
[State -1]
type = ChangeState
value = 1070
TriggerAll = var(31) != 1
triggerall = command = "QCB_x" || command = "QCB_y" || command = "QCB_z"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])  
trigger2 = movecontact

;Dive
[State -1]
type = ChangeState
value = 1030
TriggerAll = var(31) != 1
triggerall = command = "QCF_a"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1031
TriggerAll = var(31) != 1
triggerall = command = "QCF_b"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699]) 
trigger2 = movecontact


;Assasin's Slide
[State -1]
type = ChangeState
value = 1090
TriggerAll = var(31) != 1
triggerall = command = "QCF_a" 
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;Assasin's Slide
[State -1]
type = ChangeState
value = 1073
TriggerAll = var(31) != 1
triggerall = command = "QCF_b"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1034
TriggerAll = var(31) != 1
triggerall = command = "QCF_c"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,699]) 
trigger2 = movecontact

;Kikkoken_Z
[State -1]
type = ChangeState
value = 1074
TriggerAll = var(31) != 1
triggerall = command = "QCF_c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
;===========================================================================
;---------------------------------------------------------------------------

;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800 + (statetype = A)
TriggerAll = var(31) != 1
triggerall = (command = "y") || (command = "z")
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd" && (statetype = S)
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback" && (statetype = S)
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
trigger3 = command = "holdfwd" && (statetype = A)
trigger3 = p2bodydist X < 3
trigger3 = p2statetype = A
trigger4 = command = "holdback" && (statetype = A)
trigger4 = p2bodydist X < 5
trigger4 = p2statetype = A 

;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 850 
TriggerAll = var(31) != 1
triggerall = (command = "b") || (command = "c")
triggerall = statetype !=A
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd" && (statetype = S)
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback" && (statetype = S)
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

; Dash
[State -1]
type = ChangeState
value = 100
TriggerAll = var(31) != 1
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = stateno != 100
trigger1 = command != "holddown"
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; BackDash
[State -1]
type = ChangeState
value = 105
TriggerAll = var(31) != 1
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = stateno != 105
trigger1 = command != "holddown"
trigger1 = ctrl = 1



;Jacknife Kick 
[State -1]
type = ChangeState
value = 260
TriggerAll = var(31) != 1
triggerall = command = "b" 
trigger1 = stateno = 1073 || stateno = 1090
trigger1 = AnimElemtime(3) > 1

;Jacknife Kick 
[State -1]
type = ChangeState
value = 1091
TriggerAll = var(31) != 1
triggerall = command = "a" 
trigger1 = stateno = 1073 || stateno = 1090
trigger1 = AnimElemtime(3) > 1

;Tetsu Crescent slice
[State -1]
type = ChangeState
value = 1092
TriggerAll = var(31) != 1
triggerall = command = "c" 
trigger1 = stateno = 1073 || stateno = 1090
trigger1 = AnimElemtime(3) > 1

;Headbutt
[State -1]
type = ChangeState
value = 280
TriggerAll = var(31) != 1
triggerall = command = "z"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
trigger4 = (stateno = [220,230]) && movecontact
trigger5 = (stateno = [420,430]) && movecontact

;Jacknife Kick 
[State -1]
type = ChangeState
value = 260
TriggerAll = var(31) != 1
triggerall = command = "c"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
trigger4 = (stateno = [220,230]) && movecontact
trigger5 = (stateno = [420,430]) && movecontact


;---------------------------------------------------------------------------
;Standing Light Kick
[State -1]
type = ChangeState
value = 210
TriggerAll = var(31) != 1
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------


;Tricky Kick 
[State -1]
type = ChangeState
value = 270
TriggerAll = var(31) != 1
triggerall = command = "c"
triggerall = command = "holdback"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
trigger4 = (stateno = [220,230]) && movecontact
trigger5 = (stateno = [420,430]) && movecontact

;Standing Medium Kick 
[State -1]
type = ChangeState
value = 220
TriggerAll = var(31) != 1
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact


;---------------------------------------------------------------------------
;Standing Heavy Kick
[State -1]
type = ChangeState
value = 240
TriggerAll = var(31) != 1
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
trigger4 = (stateno = [220,230]) && movecontact
trigger5 = (stateno = [420,430]) && movecontact
;---------------------------------------------------------------------------
;Standing Light Punch
[State -1]
type = ChangeState
value = 200
TriggerAll = var(31) != 1
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Standing Medium Punch
[State -1]
type = ChangeState
value = 230
TriggerAll = var(31) != 1
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
;---------------------------------------------------------------------------
;Standing Heavy Punch
[State -1]
type = ChangeState
value = 250
TriggerAll = var(31) != 1
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
trigger4 = (stateno = [220,230]) && movecontact
trigger5 = (stateno = [420,430]) && movecontact
;-------------------------------------------------------------------------------
;Crouching Light Punch
[State -1]
type = ChangeState
value = 400
TriggerAll = var(31) != 1
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1]
type = ChangeState
value = 420
TriggerAll = var(31) != 1
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
;---------------------------------------------------------------------------
;Crouching Heavy Punch
[State -1]
type = ChangeState
value = 440
TriggerAll = var(31) != 1
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
trigger4 = (stateno = [220,230]) && movecontact
trigger5 = (stateno = [420,430]) && movecontact
;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1]
type = ChangeState
value = 410
TriggerAll = var(31) != 1
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1]
type = ChangeState
value = 430
TriggerAll = var(31) != 1
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
;---------------------------------------------------------------------------
;Crouching Heavy Kick
[State -1]
type = ChangeState
value = 450
TriggerAll = var(31) != 1
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = [200,210]) && movecontact
trigger3 = (stateno = [400,410]) && movecontact
trigger4 = (stateno = [220,230]) && movecontact
trigger5 = (stateno = [420,430]) && movecontact
;---------------------------------------------------------------------------
;Jumping Light Kick (neutral)
[State -1]
type = ChangeState
value = 610
TriggerAll = var(31) != 1
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping Medium Kick (neutral)
[State -1]
type = ChangeState
value = 640
TriggerAll = var(31) != 1
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,610]) && movecontact
;---------------------------------------------------------------------------
;Jumping Heavy Kick (neutral)
[State -1]
type = ChangeState
value = 670

TriggerAll = var(31) != 1
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,610]) && movecontact
trigger3 = (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Jumping Light Punch (neutral)
[State -1]
type = ChangeState
value = 600

TriggerAll = var(31) != 1
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping Medium Punch (neutral)
[State -1]
type = ChangeState
value = 630

TriggerAll = var(31) != 1
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,610]) && movecontact
;---------------------------------------------------------------------------
;Jumping Heavy Punch (neutral)
[State -1]
type = ChangeState
value = 661

TriggerAll = var(31) != 1
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,610]) && movecontact
trigger3 = (stateno = [630,640]) && movecontact

;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
TriggerAll = var(31) != 1
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;-------------------
;MEE Template Files
;   provided by
;  Kitsune Sniper
;       ***
; Thanks, Kitsune!
;-------------------
;---------------------------------------------------------------------------
;===========================================================================
;---------------------------------------------------------------------------
;Artificial Inteligence
;---------------------------------------------------------------------------
[State -2, 0]  ;ai start
type = varset
trigger1 = command = "AI1"
trigger2 = command = "AI2"
trigger3 = command = "AI3"
trigger4 = command = "AI4"
trigger5 = command = "AI5"
trigger6 = command = "AI6"
trigger7 = command = "AI7"
trigger8 = command = "AI8"
trigger9 = command = "AI9"
trigger10 = command = "AI10"
trigger11 = command = "AI11"
trigger12 = command = "AI12"
trigger13 = command = "AI13"
trigger14 = command = "AI14"
trigger15 = command = "AI15"
trigger16 = command = "AI16"
trigger17 = command = "AI17"
trigger18 = command = "AI18"
trigger19 = command = "AI19"
trigger20 = command = "AI20"
trigger21 = command = "AI21"
trigger22 = command = "AI22"
trigger23 = command = "AI23"
trigger24 = command = "AI24"
trigger25 = command = "AI25"
trigger26 = command = "AI26"
trigger27 = command = "AI27"
trigger28 = command = "AI28"
trigger29 = command = "AI29"
trigger30 = command = "AI30"
trigger31 = command = "AI31"
trigger32 = command = "AI32"
trigger33 = command = "AI33"
trigger34 = command = "AI34"
trigger35 = command = "AI35"
var(31) = 1
[State -2, Throw]
type = ChangeState
value = 850
triggerall = var(31) = 1
triggerall = power < 1000
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = (P2statetype != A) && (P2statetype != L)
triggerall = (P2Movetype != H) && (P2Movetype != A)
triggerall =  Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger1   = backedgebodydist > 70
trigger1   = (p2bodydist X = [-8,2]); && (Random <= var(31)*150)


[State -2, Throw]
type = ChangeState
value = 850
triggerall = var(31) = 1
triggerall = power < 1000
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = (P2statetype != A) && (P2statetype != L)
triggerall = (P2Movetype != H) && (P2Movetype != A)
triggerall =  Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger1   = backedgebodydist <= 70
trigger1   = (p2bodydist X = [-8,2]) ;&& (Random <= var(31)*150)


[State -2, Throw]
type = ChangeState
value = 3050
triggerall = var(31) = 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = statetype != A
triggerall = (P2statetype != A) && (P2statetype != L)
triggerall = (P2Movetype != H) && (P2Movetype != A)
triggerall =  Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger1   = backedgebodydist > 70
trigger1   = (p2bodydist X = [-8,2]); && (Random <= var(31)*150)

[State -2, Throw]
type = ChangeState
value = 3050
triggerall = var(31) = 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = statetype != A
triggerall = (P2statetype != A) && (P2statetype != L)
triggerall = (P2Movetype != H) && (P2Movetype != A)
triggerall =  Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger1   = backedgebodydist <= 70
trigger1   = (p2bodydist X = [-8,2]) ;&& (Random <= var(31)*150)

[State -2, Throw]
type = ChangeState
value = 800
triggerall = var(31) = 1
triggerall = Roundstate = 2
triggerall = P2statetype = A
triggerall = statetype = A
triggerall = P2statetype != L
triggerall = (P2Movetype != H) && (P2Movetype != A)
triggerall =  Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger1   = backedgebodydist > 70
trigger1   = (p2bodydist X = [-5,14]); && (Random <= var(31)*150)

;K
[State -2, Throw]
type = ChangeState
value = 800
triggerall = var(31) = 1
triggerall = Roundstate = 2
triggerall = statetype = A
triggerall = P2statetype = A
triggerall = P2statetype != L
triggerall = (P2Movetype != H) && (P2Movetype != A)
triggerall =  Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger1   = backedgebodydist <= 70
trigger1   = (p2bodydist X = [-5,14]); && (Random <= var(31)*150)




[State -2]
type = ChangeState
value = 40
triggerall = var(31) >= 1
triggerall = var(56) = 0
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = BackEdgeBodyDist > 50
trigger1   = Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger1   = p2statetype = L && p2movetype != H
trigger1   = (p2bodydist X = [60,85]) && (Random <= var(31)*120)
trigger1   = p2stateno = 5120
trigger1   = (EnemyNear,AnimTime <= -7)||(prevstateno = 106)
trigger2   = Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger2   = movetype = I
trigger2   = (EnemyNear,HitDefAttr = SCA,SA,HA)||(enemynear,NumProj > 0)
trigger2   = p2statetype != L && p2statetype != A
trigger2   = p2movetype != H && p2movetype = A
trigger2   = ((p2bodydist X = [110,180])&&(BackEdgeBodyDist > 30))||(p2bodydist X >= 220)
trigger2   = Random <= var(31)*130
trigger3   = Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger3   = movetype = I
trigger3   = (Power >= 2000)||(var(30) != 0)|| (var(55) = 1)
trigger3   = p2statetype != L && p2statetype != A
trigger3   = p2movetype != H && p2movetype != A
trigger3   = (p2bodydist X = [70,180])
trigger3   = Random <= var(31)*110
trigger4   = Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger4   = movetype = I
trigger4   = (EnemyNear,MoveType = A) && (Enemynear,NumHelper || Enemynear,NumProj)
trigger4   = p2statetype != L && p2statetype != A
trigger4   = (p2bodydist X >= 220)
trigger4   = Random <= var(31)*165
trigger5   = Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger5   = movetype = I
trigger5   = (EnemyNear,MoveType != A) && (P2movetype = H)
trigger5   = p2statetype != L && p2statetype = A
trigger5   = (enemynear,vel y > 0)&&(enemynear,vel x >= 0)
trigger5   = (p2bodydist X = [70,120]) && (EnemyNear,pos y = [-230,-100])
trigger5   = Random <= var(31)*150
trigger6   = Ctrl ||(stateno = [10,12])||(stateno = 21)||(stateno = 100)
trigger6   = (prevstateno = 2000)
trigger6   = (EnemyNear,MoveType != A) && (P2movetype = H)
trigger6   = p2statetype != L && p2statetype = A
trigger6   = (enemynear,vel y > 0)&&(enemynear,vel x >= 0)
trigger6   = (p2bodydist X = [10,120]) && (EnemyNear,pos y = [-230,-80])
trigger6   = Random <= var(31)*180



[State -1, Guard]
type = ChangeState
value = 120
triggerall = var(31) >= 1 
triggerall = ctrl && stateno != 120
trigger1 = inguarddist
trigger1 = !enemy, MoveGuarded

[State -2, Jump Light Kick]
type = ChangeState
value = 40;1070
triggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Ctrl
triggerall = random <= 500
triggerall = statetype != A
triggerall = stateno != 15
trigger1   = (p2statetype = A)&&(p2movetype != A)
trigger1   = (p2bodydist X = [10,20])
trigger1   = (p2bodydist Y = [-20,-10])
trigger2 = p2statetype = C
trigger2 = p2movetype != A
trigger2 = p2bodydist X <= 70 
[State -2, Jump Light Kick]
type = ChangeState
value = 1010;2070
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Ctrl
triggerall = random <= 600
triggerall = statetype != A
triggerall = stateno != 105
trigger1   = (p2statetype = A)&&(p2movetype != A)
trigger1   = (p2bodydist X = [10,20])
trigger1   = (p2bodydist Y = [-20,-10])
trigger2 = p2statetype = C
trigger2 = p2movetype != A
trigger2 = p2bodydist X <= 70 

[State -2, Jump Light Kick]
type = ChangeState
value = 410
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Ctrl
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = p2statetype = S
trigger1 = p2movetype != A
trigger1 = p2bodydist X <= 50 


[State -1, Hadouken AI]
type = ChangeState
Value = 1002
TriggerAll = var(31)
TriggerAll = !Numproj
TriggerAll = random <= 500
TriggerAll = StateType != A
trigger1 = p2bodydist x > 160
Trigger1 = p2MoveType = A
Trigger1 = enemy, vel x != 0 || p2StateNo != [1000, 2999]
Trigger1 = p2StateNo != [3000, 4999]
Trigger1 = ctrl || stateno = 100
trigger2 = p2bodydist x > 150
Trigger2 = Random < 50 || p2StateNo = [5120, 5210]
Trigger2 = ctrl || stateno = 100
Trigger3 = p2bodydist x > 30
Trigger3 = p2StateType != A ||(p2MoveType = H && p2StateNo = [6000, 6005])
Trigger3 = Movecontact
Trigger3 = (StateNo = 300 || StateNo = 310 || StateNo = 500) || StateNo = 450

[State -1, Hadouken AI]
type = ChangeState
Value = 1041
TriggerAll = var(31)
TriggerAll = !Numproj
TriggerAll = StateType != A
trigger1 = p2bodydist x > 160
Trigger1 = p2MoveType = A
Trigger1 = enemy, vel x != 0 || p2StateNo != [1000, 2999]
Trigger1 = p2StateNo != [3000, 4999]
Trigger1 = ctrl || stateno = 100
trigger2 = p2bodydist x > 150
Trigger2 = Random < 50 || p2StateNo = [5120, 5210]
Trigger2 = ctrl || stateno = 100
Trigger3 = p2bodydist x > 30
Trigger3 = p2StateType != A ||(p2MoveType = H && p2StateNo = [6000, 6005])
Trigger3 = Movecontact
Trigger3 = (StateNo = 300 || StateNo = 310 || StateNo = 500) || StateNo = 450


[State -2, Jump Light Kick]
type = ChangeState
value = 410
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
TriggerAll = random <= 300
triggerall = Ctrl
triggerall = statetype != A
triggerall = stateno = 52
trigger1 = p2statetype != A
trigger1 = p2movetype = H
trigger1 = p2bodydist X <= 50 
[State -2, Jump Light Kick]
type = ChangeState
value = 2020
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Ctrl
TriggerAll = random <= 800
triggerall = power >= 500
triggerall = statetype != A
triggerall = stateno = 52
trigger1 = p2statetype != A
trigger1 = p2movetype = H
trigger1 = p2bodydist X <= 50 


[State -2, Jump Light Kick]
type = ChangeState
value = 410
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Ctrl
triggerall = statetype != A
triggerall = stateno = 52
trigger1 = p2statetype = S
trigger1 = p2movetype = H
trigger1 = p2bodydist X <= 50 

[State -2, Jump Light Kick]
type = ChangeState
value = 430
TriggerAll = var(31) >= 1
TriggerAll = random <= 300
triggerall = Roundstate = 2
triggerall = p2bodydist X <= 50
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 410
trigger1 = movehit


[State -2, Jump Light Kick]
type = ChangeState
value = 230
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
triggerall = Roundstate = 2
triggerall = p2bodydist X <= 50
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 410
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 250
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = p2bodydist X <= 50
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 230
trigger1 = movehit


[State -2, Jump Light Kick]
type = ChangeState
value = 1002
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
triggerall = Roundstate = 2
triggerall = (p2bodydist X = [43,70])
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 250
trigger1 = movehit
[State -2, Jump Light Kick]
type = ChangeState
value = 2000
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
TriggerAll = power >= 500
triggerall = Roundstate = 2
triggerall = (p2bodydist X = [43,70])
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 250
trigger1 = movehit


;[State -2, Jump Light Kick]
;type = ChangeState
;value = 1040
;TriggerAll = var(31) >= 1
;triggerall = Roundstate = 2
;triggerall = statetype != A
;triggerall = stateno != 105
;trigger1 = stateno = 1002
;trigger1 = time = 24
;[State -2, Jump Light Kick]
;type = ChangeState
;value = 1041
;TriggerAll = var(31) >= 1
;triggerall = Roundstate = 2
;triggerall = statetype != A
;triggerall = stateno != 105
;trigger1 = stateno = 2000
;trigger1 = time = 22
[State -2, Jump Light Kick]
type = ChangeState
value = 410
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
TriggerAll = power < 3000
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
triggerall = p2bodydist X <= 2
trigger1 = stateno = 1040


[State -2, Jump Light Kick]
type = ChangeState
value = 2020
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
triggerall = p2bodydist X <= 2
trigger1 = stateno = 1040
[State -2, Jump Light Kick]
type = ChangeState
value = 1070
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = p2statetype = C
triggerall = p2bodydist X >= 51
triggerall = stateno != 105
trigger1 = stateno = 410
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 260
TriggerAll = var(31) >= 1
TriggerAll = random <= 350
triggerall = Roundstate = 2
triggerall = power < 2000
triggerall = statetype != A
triggerall = p2statetype = C
triggerall = stateno != 105
trigger1 = stateno = 410
trigger1 = moveguarded
[State -2, Jump Light Kick]
type = ChangeState
value = 1070
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power < 2000
TriggerAll = random <= 350
triggerall = statetype != A
triggerall = p2statetype = C
triggerall = stateno != 105
trigger1 = stateno = 410
trigger1 = moveguarded

[State -2, Jump Light Kick]
type = ChangeState
value = 40
TriggerAll = var(31) >= 1
TriggerAll = random <= 350
triggerall = power < 2000
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = p2statetype = C
triggerall = stateno != 105
trigger1 = stateno = 410
trigger1 = moveguarded

[State -2, Jump Light Kick]
type = ChangeState
value = 3000
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 2000
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 230
trigger1 = time = 10
trigger1 = p2movetype != H


[State -2, Jump Light Kick]
type = ChangeState
value = 3050
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 3000
trigger1 = moveguarded


[State -2, Jump Light Kick]
type = ChangeState
value = 3000
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 2000
triggerall = statetype != A
triggerall = p2statetype = C
triggerall = stateno != 105
trigger1 = stateno = 410
trigger1 = moveguarded
[State -2, Jump Light Kick]
type = ChangeState
value = 1073
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Random <= 500
triggerall = statetype != A
triggerall = p2statetype = S
triggerall = p2bodydist X >= 51
triggerall = stateno != 105
trigger1 = stateno = 430
trigger1 = time = 10

[State -2, Jump Light Kick]
type = ChangeState
value = 1040
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = p2statetype = S
triggerall = p2bodydist X >= 51
triggerall = stateno != 105
trigger1 = stateno = 430
trigger1 = time = 10

[State -2, Jump Light Kick]
type = ChangeState
value = 1040
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = p2statetype != A
triggerall = p2bodydist X >= 51
triggerall = stateno != 105
trigger1 = stateno = 230
trigger1 = time = 10

[State -2, Jump Light Kick]
type = ChangeState
value = 2090
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = p2statetype = S
triggerall = p2bodydist X >= 51
triggerall = stateno != 105
trigger1 = stateno = 430
trigger1 = time = 10
[State -2, Jump Light Kick]
type = ChangeState
value = 1092
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 1073
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 1094
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = random <= 500
triggerall = stateno != 105
trigger1 = stateno = 1093
trigger1 = movehit && time = 10

[State -2, Jump Light Kick]
type = ChangeState
value = 3090
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = stateno != 105
trigger1 = stateno = 1094
trigger1 = movehit
trigger2 = stateno = 3042
trigger2 = time = 1
;trigger2 = time = 9
;trigger2 = random <= 400
[State -2, Jump Light Kick]
type = ChangeState
value = 3090
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = stateno != 105
trigger1 = moveguarded
trigger1 = stateno = 1011
trigger1 = p2statetype = C

[State -2, Jump Light Kick]
type = ChangeState
value = 3045
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = stateno != 105
trigger1 = stateno = 1094
trigger1 = movehit
trigger2 = stateno = 3092
trigger2 = time = 14
trigger2 = random <= 200
;trigger2 = time = 9
;trigger2 = random <= 400

[State -2, Jump Light Kick]
type = ChangeState
value = 3070
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = stateno != 105
trigger1 = stateno = 1094
trigger1 = movehit
trigger2 = stateno = 3092
trigger2 = time = 14
;trigger2 = time = 9
;trigger2 = random <= 400
[State -2, Jump Light Kick]
type = ChangeState
value = 3070
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = stateno != 105
trigger1 = stateno = 1093
trigger1 = movehit && time >= 33
[State -2, Jump Light Kick]
type = ChangeState
value = 450
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 430
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 1075
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = stateno = 450
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 610
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype = A
triggerall = ctrl
triggerall = stateno != 105
trigger1 = p2movetype = H
trigger1 = p2bodydist X <= 70

[State -2, Jump Light Kick]
type = ChangeState
value = 640
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype = A
triggerall = p2bodydist X <= 55
triggerall = stateno != 105
trigger1 = stateno = 610
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 670
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 640
trigger1 = movehit
[State -2, Jump Light Kick]
type = ChangeState
value = 1020
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Ctrl
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = p2statetype = A
trigger1 = p2movetype = A
trigger1 = (p2bodydist Y = [-110,-10])
trigger1 = p2bodydist X <= 110
[State -2, Jump Light Kick]
type = ChangeState
value = 40
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = Ctrl
triggerall = statetype != A
triggerall = stateno != 105
trigger1 = p2statetype = A
trigger1 = p2movetype = H
trigger1 = prevstateno = 1075
trigger2 = p2statetype = A
trigger2 = p2movetype = H
trigger2 = prevstateno = 1075
trigger2 = stateno = 100
[state -2]
type = varset
triggerall = var(31) >= 1
trigger1 = stateno = 1075 && movehit
sysvar(1) = 1 
[state -2]
type = varset
triggerall = var(31) >= 1
trigger1 = prevstateno = 1075
trigger2 = p2movetype = H
sysvar(1) = 1 

[State -2, Jump Light Kick]
type = ChangeState
value = 1082
TriggerAll = var(31) >= 1
TriggerAll = random <= 350
triggerall = p2bodydist Y < 0
triggerall = Roundstate = 2
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 670
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 3090
TriggerAll = var(31) >= 1
TriggerAll = random <= 100
triggerall = p2bodydist Y < 0
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = statetype = A
triggerall = power <= 2999
triggerall = stateno != 105
trigger1 = stateno = 1082
trigger1 = movehit
trigger2 = stateno = 1084
trigger2 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 3045
TriggerAll = var(31) >= 1
TriggerAll = random <= 100
triggerall = p2bodydist Y < 0
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = power <= 2999
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 1082
trigger1 = movehit
trigger2 = stateno = 1084
trigger2 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 3070
TriggerAll = var(31) >= 1
TriggerAll = random <= 100
triggerall = p2bodydist Y < 0
triggerall = power <= 2999
triggerall = Roundstate = 2
triggerall = power >= 1000
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 1082
trigger1 = movehit
trigger2 = stateno = 1084
trigger2 = movehit


[State -2, Jump Light Kick]
type = ChangeState
value = 1084
TriggerAll = var(31) >= 1
TriggerAll = random <= 350
triggerall = p2bodydist Y < 0
triggerall = Roundstate = 2
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 670
trigger1 = movehit
[State -2, Jump Light Kick]
type = ChangeState
value = 2080
TriggerAll = var(31) >= 1
TriggerAll = power >= 500
TriggerAll = power <= 3000
TriggerAll = random <= 350
triggerall = p2bodydist Y < 0
triggerall = Roundstate = 2
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 670
trigger1 = movehit

[State -2, Jump Light Kick]
type = ChangeState
value = 2000
triggerAll = var(31) >= 1
TriggerAll = power >= 500
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
;trigger1 = prevstateno = 52
trigger1 = time = 13
trigger1 = ctrl
trigger1 = p2movetype = H
trigger1 = enemy, Vel y >= 4
trigger1 = p2statetype != L


[State -2, Jump Light Kick]
type = ChangeState
value = 2000
triggerAll = var(31) >= 1
TriggerAll = power >= 500
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
TriggerAll = random <= 350
;trigger1 = prevstateno = 52
trigger1 = time = 15
trigger1 = ctrl
trigger1 = p2movetype = H
trigger1 = enemy, Vel y >= 1
trigger1 = p2statetype != L

[State -2, Jump Light Kick]
type = ChangeState
value = 5120
TriggerAll = stateno = 5122
trigger1 = time = 620
trigger1 = alive

[State -2, Jump Light Kick]
type = ChangeState
value = 2000
TriggerAll = var(31) >= 1
TriggerAll = power >= 500
triggerall = Roundstate = 2
triggerall = statetype != A
triggerall = stateno != 105
;trigger1 = prevstateno = 52
trigger1 = time = 10
trigger1 = ctrl
trigger1 = p2movetype = H
trigger1 = enemy, Vel y <= -2
trigger1 = p2statetype != L

[State -2, Jump Light Kick]
type = ChangeState
value = 1030
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
triggerall = Roundstate = 2
triggerall = p2bodydist Y > 10
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 670
trigger1 = movecontact

[State -2, Jump Light Kick]
type = ChangeState
value = 1031
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
triggerall = Roundstate = 2
triggerall = p2bodydist Y > 10
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = stateno = 670
trigger1 = movecontact

[State -2, Jump Light Kick]
type = ChangeState
value = 1030
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
TriggerAll = ctrl
triggerall = Roundstate = 2
triggerall = p2bodydist X < 40
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = p2statetype = C

[State -2, Jump Light Kick]
type = ChangeState
value = 1062
TriggerAll = var(31) >= 1
;TriggerAll = random <= 700
TriggerAll = ctrl
triggerall = Roundstate = 2
triggerall = p2bodydist X < 40
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = p2statetype = S

[State -2, Jump Light Kick]
type = ChangeState
value = 3045
TriggerAll = var(31) >= 1
TriggerAll = random <= 700
TriggerAll = power >= 1000
triggerall = Roundstate = 2
triggerall = p2bodydist X < 40
triggerall = stateno = 1021
trigger1 = p2movetype = H && movehit
trigger1 = time = 19



[State -2, Jump Light Kick]
type = ChangeState
value = 3080
TriggerAll = var(31) >= 1
TriggerAll = random <= 700
TriggerAll = power >= 1000
triggerall = Roundstate = 2
triggerall = p2bodydist X < 40
triggerall = stateno = 861
trigger1 = p2movetype = H && time = 17


[State -2, Jump Light Kick]
type = ChangeState
value = 2030
TriggerAll = var(31) >= 1
TriggerAll = random <= 500
TriggerAll = power >= 500
TriggerAll = ctrl
triggerall = Roundstate = 2
triggerall = p2bodydist X < 40
triggerall = statetype = A
triggerall = stateno != 105
trigger1 = p2statetype = C


[State -2, Jump Light Kick]
type = ChangeState
value = 440
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = ctrl
triggerall = power < 3000
triggerall = statetype != A
triggerall = stateno != 105
triggerall = p2movetype = H
triggerall = p2statetype = A
;trigger1 = p2stateno = 5050
trigger1 = enemy,Vel X <= 0
trigger1 = p2bodydist Y >= -60
trigger1 = p2bodydist X <= 70



[State -2, Jump Light Kick]
type = ChangeState
value = 4000
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
triggerall = ctrl
triggerall = power = 3000
triggerall = statetype != A
triggerall = stateno != 105
triggerall = p2movetype = H
triggerall = p2statetype = A
;trigger1 = p2stateno = 5050
trigger1 = enemy,Vel X <= 0
trigger1 = p2bodydist Y >= -100
trigger1 = p2bodydist Y <= -50
trigger1 = p2bodydist X <= 70
trigger1 = p2bodydist X > 0

[State -2, Jump Light Kick]
type = ChangeState
value = 40
TriggerAll = var(31) >= 1
triggerall = Roundstate = 2
;triggerall = Ctrl
triggerall = statetype != A
;triggerall = p2bodydist Y <= -40
;triggerall = p2bodydist X >= 70
;trigger1 = p2statetype = A
;trigger1 = p2movetype = H
;trigger1 = p2stateno = 5050
;trigger1 = prevstateno != 1082
trigger1 = p2statetype = A
trigger1 = p2movetype = H
trigger1 = stateno = 440 && movehit
trigger1 = time = 10
trigger2 = p2statetype = A
trigger2 = p2movetype = H
trigger2 = stateno = 440 && movehit
trigger2 = time = 10
trigger2 = stateno = 100

[state -2]
type = varset
triggerall = var(31) >= 1
trigger1 = stateno = 440 && movehit
sysvar(1) = 1 
[state -2]
type = varset
triggerall = var(31) >= 1
trigger1 = prevstateno = 440
trigger2 = p2movetype = H
sysvar(1) = 1 

[state -2]
type = playsnd
value = 78,131
trigger1 = var(44) = 2
trigger1 = var(44) != 5
trigger1 = life <= 150
trigger1 = life != 0
;trigger1 = time = 0
channel = 6

[state -2]
type = varset
var(44) = 5
trigger1 = var(44) = 2
trigger1 = life <= 150
;trigger1 = time = 0
